from PyQt5 import QtWidgets

from point_spectra_gui.ui.RegressionPredict import Ui_Form
from point_spectra_gui.util.Modules import Modules


class RegressionPredict(Ui_Form, Modules):
    count = -1

    def __init__(self):
        RegressionPredict.count += 1
        self.curr_count = RegressionPredict.count

    def delete(self):
        try:
            RegressionPredict.count -= 1
        except IndexError:
            pass

    def setupUi(self, Form):
        super().setupUi(Form)
        Modules.setupUi(self, Form)

    def get_widget(self):
        return self.formGroupBox

    def connectWidgets(self):
        self.setListWidget(self.chooseDataListWidget, self.datakeys)
        self.setComboBox(self.chooseModelComboBox, self.modelkeys)

    def setup(self):
        datakeys = [str(i.text()) for i in self.chooseDataListWidget.selectedItems()]
        modelkey = self.chooseModelComboBox.currentText()
        try:
            for datakey in datakeys:
                self.list_amend(self.predictkeys, self.curr_count, modelkey + ' - ' + datakey + ' - Predict')
        except Exception as e:
            print(e)

    def run(self):
        datakeys = [str(i.text()) for i in self.chooseDataListWidget.selectedItems()]
        modelkey = self.chooseModelComboBox.currentText()
        try:
            for datakey in datakeys:
                print('Predicting '+datakey)
                data_tmp = self.data[datakey].df[self.model_xvars[modelkey]]
                data_tmp.fillna(value=0, inplace=True)
                prediction = self.models[modelkey].predict(data_tmp)
                predictname = ('predict', modelkey + ' - ' + datakey + ' - Predict')
                self.data[datakey].df[predictname] = prediction
        except Exception as e:
            print(e)


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)

    Form = QtWidgets.QWidget()
    ui = RegressionPredict()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())



from PyQt5 import QtWidgets

from point_spectra_gui.ui.SpecDeriv import Ui_Form
from point_spectra_gui.util.Modules import Modules
from point_spectra_gui.util.spectral_data import spectral_data
from libpysat.transform.deriv import deriv

class SpecDeriv(Ui_Form, Modules):
    def setupUi(self, Form):
        super().setupUi(Form)
        Modules.setupUi(self, Form)

    def get_widget(self):
        return self.formGroupBox

    def connectWidgets(self):
        self.setComboBox(self.chooseDataToDerivComboBox, self.datakeys)

    def run(self):
        datakey = self.chooseDataToDerivComboBox.currentText()
        new_datakey = datakey + ' - Derivative'
        self.datakeys.append(new_datakey)
        self.data[new_datakey] = spectral_data(deriv(self.data[datakey].df))
        print("Derivative Applied")


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)

    Form = QtWidgets.QWidget()
    ui = SpecDeriv()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())



import numpy as np
import pandas as pd
from PyQt5 import QtWidgets
from point_spectra_gui.util import Qtickle
from libpysat.regression import cv
from point_spectra_gui.util.spectral_data import spectral_data
from point_spectra_gui.core.crossValidateMethods import *
from point_spectra_gui.ui.CrossValidation import Ui_Form
from point_spectra_gui.util.Modules import Modules
from sklearn.model_selection import ParameterGrid, LeaveOneGroupOut


class CrossValidation(Ui_Form, Modules):
    count = -1

    def setupUi(self, Form):
        self.Form = Form
        super().setupUi(Form)
        Modules.setupUi(self, Form)
        self.regressionMethods()

    def get_widget(self):
        return self.groupLayout

    def make_regression_widget(self, alg, params=None):
        self.hideAll()
        print(alg)
        try:
            self.alg[alg].setHidden(False)
        except:
            pass

    def connectWidgets(self):
        self.algorithm_list = ['Choose an algorithm',
                               'ARD',
                               'BRR',
                               'Elastic Net',
                               'GP',
                               # 'KRR',  This needs more work since it requires parameters for the kernel passed as an object
                               'LARS',
                               'LASSO',
                               # 'LASSO LARS', - this also need to be debugged
                               'OLS',
                               'OMP',
                               'PLS',
                               'Ridge',
                               'SVR']

        self.setComboBox(self.chooseDataComboBox, self.datakeys)
        self.setComboBox(self.chooseAlgorithmComboBox, self.algorithm_list)
        self.yMaxDoubleSpinBox.setMaximum(999999)
        self.yMinDoubleSpinBox.setMaximum(999999)
        self.yMaxDoubleSpinBox.setValue(100)
        self.changeComboListVars(self.yVariableList, self.yvar_choices())
        self.changeComboListVars(self.xVariableList, self.xvar_choices())
        self.xvar_choices()
        self.chooseAlgorithmComboBox.currentIndexChanged.connect(
            lambda: self.make_regression_widget(self.chooseAlgorithmComboBox.currentText()))
        self.chooseDataComboBox.currentIndexChanged.connect(
            lambda: self.changeComboListVars(self.yVariableList, self.yvar_choices()))
        self.chooseDataComboBox.currentIndexChanged.connect(
            lambda: self.changeComboListVars(self.xVariableList, self.xvar_choices()))

    def getGuiParams(self):
        """
        Overriding Modules' getGuiParams, because I'll need to do a list of lists
        in order to obtain the regressionMethods' parameters
        """
        self.qt = Qtickle.Qtickle(self)
        s = []
        s.append(self.qt.guiSave())
        for items in self.alg:
            s.append(self.alg[items].getGuiParams())
        return s

    def setGuiParams(self, dict):
        self.qt = Qtickle.Qtickle(self)
        self.qt.guiRestore(dict[0])
        keys = list(self.alg.keys())
        for i in range(len(dict)):
            self.alg[keys[i - 1]].setGuiParams(dict[i])

    def selectiveSetGuiParams(self, dict):
        """
        Override Modules' selective Restore function

        Setup Qtickle
        selectively restore the UI, the data to do that will be in the 0th element of the dictionary
        We will then iterate through the rest of the dictionary
        Will now restore the parameters for the algorithms in the list, Each of the algs have their own selectiveSetGuiParams

        :param dict:
        :return:
        """
        self.qt = Qtickle.Qtickle(self)
        self.qt.selectiveGuiRestore(dict[0])
        keys = list(self.alg.keys())
        for i in range(len(dict)):
            self.alg[keys[i - 1]].selectiveSetGuiParams(dict[i])

    def setup(self):
        try:
            method = self.chooseAlgorithmComboBox.currentText()
            datakey = self.chooseDataComboBox.currentText()
            xvars = [str(x.text()) for x in self.xVariableList.selectedItems()]
            yvars = [('comp', str(y.text())) for y in self.yVariableList.selectedItems()]
            yrange = [self.yMinDoubleSpinBox.value(), self.yMaxDoubleSpinBox.value()]
            # Warning: Params passing through cv.cv(params) needs to be in lists
            # Example: {'n_components': [4], 'scale': [False]}
            params, modelkey = self.alg[self.chooseAlgorithmComboBox.currentText()].run()

            #if the method supports it, separate out alpha from the other parameters and prepare for calculating path
            path_methods =  ['Elastic Net', 'LASSO']#, 'Ridge']
            if method in path_methods:
                alphas = params.pop('alpha')
            else:
                alphas = None

            paramgrid = list(ParameterGrid(params))  # create a grid of parameter permutations
            cv_obj = cv.cv(paramgrid)
            cvpredictkeys = []
            cvmodelkeys = []
            for i in range(len(paramgrid)):
                if alphas is not None:
                    for j in range(len(alphas)):
                        keytemp = '"' + method + ' - ' + yvars[0][-1] + ' - CV - Alpha:' + str(alphas[j]) + ' - ' + str(paramgrid[i]) + '"'
                        cvpredictkeys.append(keytemp)
                        keytemp = '"' + method + ' - ' + yvars[0][-1] + ' - Cal - Alpha:' + str(
                            alphas[j]) + ' - ' + str(paramgrid[i]) + '"'
                        cvpredictkeys.append(keytemp)

                        modelkeytemp = "{} - {} - ({}, {}) Alpha: {}, {}".format(method, yvars[0][-1], yrange[0], yrange[1],
                                                                             alphas[j], paramgrid[i])
                        cvmodelkeys.append(modelkeytemp)

                else:
                    keytemp = '"'+method+'- Cal -' + str(paramgrid[i]) + '"'
                    cvpredictkeys.append(keytemp)
                    keytemp = '"' + method + '- Cal -' + str(paramgrid[i]) + '"'
                    cvpredictkeys.append(keytemp)

                    modelkeytemp = "{} - {} - ({}, {}) {}".format(method, yvars[0][-1], yrange[0], yrange[1], paramgrid[i])
                    cvmodelkeys.append(modelkeytemp)

            for key in cvpredictkeys:
                self.list_amend(self.predictkeys, len(self.predictkeys), key)
                self.data[datakey].df[('predict',key)] = 9999  #Need to fill the data frame with dummy values until CV is actually run

            for n, key in enumerate(cvmodelkeys):
                self.list_amend(self.modelkeys, len(self.modelkeys), key)
                self.modelkeys.append(key)
                self.model_xvars[key] = xvars
                self.model_yvars[key] = yvars
                if method != 'GP':
                    coef = self.data[datakey].df[xvars[0]].columns.values*0.0+9999  #Fill with dummy coeffs before model is run
                    coef = pd.DataFrame(coef)
                    coef.index = pd.MultiIndex.from_tuples(self.data[datakey].df[xvars].columns.values)
                    coef = coef.T
                    coef[('meta', 'Model')] = key
                    try:
                        coef[('meta', 'Intercept')] = 0 #Fill intercept with zeros prior to model run
                    except:
                        pass
                    try:
                        self.data['Model Coefficients'] = spectral_data(
                            pd.concat([self.data['Model Coefficients'].df, coef]))
                    except:
                        self.data['Model Coefficients'] = spectral_data(coef)
                        self.datakeys.append('Model Coefficients')

            self.list_amend(self.datakeys, len(self.datakeys), 'CV Results ' + modelkey)
        except:
            pass


    def run(self):
        method = self.chooseAlgorithmComboBox.currentText()
        datakey = self.chooseDataComboBox.currentText()
        xvars = [str(x.text()) for x in self.xVariableList.selectedItems()]
        yvars = [('comp', str(y.text())) for y in self.yVariableList.selectedItems()]
        yrange = [self.yMinDoubleSpinBox.value(), self.yMaxDoubleSpinBox.value()]
        # Warning: Params passing through cv.cv(params) needs to be in lists
        # Example: {'n_components': [4], 'scale': [False]}
        params, modelkey = self.alg[self.chooseAlgorithmComboBox.currentText()].run()

        #if the method supports it, separate out alpha from the other parameters and prepare for calculating path
        path_methods =  ['Elastic Net', 'LASSO']#, 'Ridge']
        if method in path_methods:
            calc_path = True
            alphas = params.pop('alpha')
        else:
            alphas = None
            calc_path = False
        y = np.array(self.data[datakey].df[yvars])
        match = np.squeeze((y > yrange[0]) & (y < yrange[1]))
        data_for_cv = spectral_data(self.data[datakey].df.ix[match])
        paramgrid = list(ParameterGrid(params))  # create a grid of parameter permutations
        cv_obj = cv.cv(paramgrid)
        try:
            cv_iterator = LeaveOneGroupOut().split(data_for_cv.df[xvars], data_for_cv.df[yvars], data_for_cv.df[
                ('meta', 'Folds')])  # create an iterator for cross validation based on the predefined folds
            n_folds = LeaveOneGroupOut().get_n_splits(groups=data_for_cv.df[('meta', 'Folds')])

        except:
            print('***No folds found! Did you remember to define folds before running cross validation?***')

        self.data[datakey].df, self.cv_results, cvmodels, cvmodelkeys, cvpredictkeys = cv_obj.do_cv(data_for_cv.df, cv_iterator, xcols=xvars,
                                                                                     ycol=yvars, yrange=yrange, method=method,
                                                                                     alphas = alphas, calc_path = calc_path, n_folds = n_folds)
        for key in cvpredictkeys:
            self.list_amend(self.predictkeys, len(self.predictkeys), key)

        for n, key in enumerate(cvmodelkeys):
            self.list_amend(self.modelkeys, len(self.modelkeys), key)
            self.modelkeys.append(key)
            self.models[key] = cvmodels[n]
            self.model_xvars[key] = xvars
            self.model_yvars[key] = yvars
            if method != 'GP':
                coef = np.squeeze(cvmodels[n].model.coef_)
                coef = pd.DataFrame(coef)
                coef.index = pd.MultiIndex.from_tuples(self.data[datakey].df[xvars].columns.values)
                coef = coef.T
                coef[('meta', 'Model')] = key
                try:
                    coef[('meta', 'Intercept')] = cvmodels[n].model.intercept_
                except:
                    pass
                try:
                    self.data['Model Coefficients'] = spectral_data(
                        pd.concat([self.data['Model Coefficients'].df, coef]))
                except:
                    self.data['Model Coefficients'] = spectral_data(coef)
                    self.datakeys.append('Model Coefficients')

        self.datakeys.append('CV Results ' + modelkey)
        self.data['CV Results ' + modelkey] = self.cv_results

    def yvar_choices(self):
        try:
            yvarchoices = self.data[self.chooseDataComboBox.currentText()].df['comp'].columns.values
            yvarchoices = [i for i in yvarchoices if not 'Unnamed' in i]  # remove unnamed columns from choices
        except:
            yvarchoices = ['No composition columns!']
        return yvarchoices

    def xvar_choices(self):
        try:
            xvarchoices = self.data[self.chooseDataComboBox.currentText()].df.columns.levels[0].values
            xvarchoices = [i for i in xvarchoices if not 'Unnamed' in i]  # remove unnamed columns from choices
        except:
            xvarchoices = ['No valid choices!']
        return xvarchoices

    def hideAll(self):
        for a in self.alg:
            self.alg[a].setHidden(True)

    def regressionMethods(self):
        self.alg = {'ARD': cv_ARD.Ui_Form(),
                    'BRR': cv_BayesianRidge.Ui_Form(),
                    'Elastic Net': cv_ElasticNet.Ui_Form(),
                    'GP': cv_GP.Ui_Form(),
                    #'KRR': cv_KRR.Ui_Form(),
                    'LARS': cv_LARS.Ui_Form(),
                    'LASSO': cv_Lasso.Ui_Form(),
                    #'LASSO LARS': cv_LassoLARS.Ui_Form(),
                    'OLS': cv_OLS.Ui_Form(),
                    'OMP': cv_OMP.Ui_Form(),
                    'PLS': cv_PLS.Ui_Form(),
                    'Ridge': cv_Ridge.Ui_Form(),
                    'SVR': cv_SVR.Ui_Form()
                    }

        for item in self.alg:
            self.alg[item].setupUi(self.Form)
            self.algorithmLayout.addWidget(self.alg[item].get_widget())
            self.alg[item].setHidden(True)


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = CrossValidation()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())



import pandas as pd
from PyQt5 import QtWidgets

from point_spectra_gui.ui.CombineDataSets import Ui_Form
from point_spectra_gui.util.Modules import Modules
from point_spectra_gui.util.spectral_data import spectral_data

class CombineDataSets(Ui_Form, Modules):
    """
    Combine the various datasets into one bigger dataset
    This is still in Beta and needs to be improved.
    This is in part due to the fact that we are using multidimensional columns to reference data
    """

    def setupUi(self, Form):
        self.Form = Form
        super().setupUi(Form)
        Modules.setupUi(self, Form)

    def get_widget(self):
        return self.formGroupBox

    def connectWidgets(self):
        self.setComboBox(self.dataSet1ComboBox, self.datakeys)
        self.setComboBox(self.dataSet2ComboBox, self.datakeys)

    def run(self):
        dataSet1 = self.dataSet1ComboBox.currentText()
        dataSet2 = self.dataSet2ComboBox.currentText()
        newkey = self.outputToDataSetLineEdit.text()
        self.datakeys.append(newkey)
        self.data[newkey] = spectral_data(pd.concat([self.data[dataSet1].df, self.data[dataSet2].df], ignore_index=True))


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())



import inspect

from PyQt5.QtCore import QSettings
from PyQt5.QtWidgets import *
from point_spectra_gui.util import Qtickle


class Modules:
    """
    Modules class that UI modules will inherit from.

    *Note: Rigorous prototyping is still occurring
    So, naturally, assume that something in this class
    is always getting changed or added to better serve
    all cases in each UI class.

    ...

    Since `Modules` is shared among all the UI
    classes it would make sense that we would have
    some variables, that are necessary among all these
    classes, be put here in a high place where they
    can be referenced often.
    """
    data = {}  # initialize with an empty dict to hold data frames
    datakeys = []  # hold all the specific key for a specific data frame
    modelkeys = []
    models = {}  # For regression training
    predictkeys = []
    outpath = './'  # Default outpath; can be changed with OutputFolder.py
    figs = {}
    figname = []
    model_xvars = {}
    model_yvars = {}
    parent = []

    def __init__(self):
        self.qtickle = Qtickle.Qtickle(self)
        self.settings = QSettings('USGS', 'PPSG')

    def setupUi(self, Form):
        self.Form = Form
        self.Form.mousePressEvent = self.mousePressEvent
        self.connectWidgets()

    def mousePressEvent(self, QMouseEvent):
        """
        TODO: Add right click event
        The hope is that we can add a right click dialogue for users
        The dialogue would give the option to delete particular
        modules from the UI, or insert modules, or copy modules.
        """
        # TODO Add mouse Event
        pass
        # print("Right Button Clicked {}".format(type(self).__name__))

    def get_widget(self):
        """
        This function specifies the variable that holds the
        styling. Use this function to get the variable

        :return:
        """
        raise NotImplementedError(
            'The method "get_widget()" was not found in the module {}'.format(type(self).__name__))

    def connectWidgets(self):
        """
        Connect the necessary widgets.

        :return:
        """
        raise NotImplementedError(
            'The method "connectWidgets()" was not found in the module {}'.format(type(self).__name__))

    def disconnectWidgets(self):
        """
        Disconnect the widgets that way we don't run into this problem
        https://stackoverflow.com/questions/3530590/qt-signals-and-slot-connected-twice-what-happens#_=_

        :return:
        """
        self.qtickle = Qtickle.Qtickle(self)
        self.qtickle.guiDisonnect()

    def getMainWindowParent(self):
        return self.parent[0]

    def guiChanged(self):
        self.qtickle = Qtickle.Qtickle(self)
        self.qtickle.guiChanged(self.getMainWindowParent().setupModules)

    def getGuiParams(self):
        """
        Return the contents from lineEdits, comboBoxes, etc.

        :return:
        """
        self.qtickle = Qtickle.Qtickle(self)
        s = self.qtickle.guiSave()
        return s

    def setGuiParams(self, dict):
        """
        Using a dictionary, restore the UI

        :param dict:
        :return:
        """
        self.qtickle = Qtickle.Qtickle(self)
        self.qtickle.guiRestore(dict)

    def selectiveSetGuiParams(self, dict):
        """
        Selectively restore the UI.
        We don't want to lose the content we have selected
        but we don't want to override crucial information either

        :param dict:
        :return:
        """
        self.qtickle = Qtickle.Qtickle(self)
        self.qtickle.selectiveGuiRestore(dict)

    def setup(self):
        """
        This is a stripped down version of run()
        Each Module's functionality will be quickly ran through, so we have
        at least something in the UI to work with

        :return:
        """
        pass

    def run(self):
        """
        Each Module's functionality will be ran in this function.
        You will define what will happen to the data and parameters in here
        :return:
        """
        raise NotImplementedError('The method "run()" was not found in the module {}'.format(type(self).__name__))

    def delete(self):
        """
        In some particular cases, the UI needs to have some information dumped.
        This is a chance to do that.

        :return:
        """
        pass

    def isEnabled(self):
        """
        Checks to see if current widget isEnabled or not
        :return:
        """
        return self.get_widget().isEnabled()

    def setDisabled(self, bool):
        """
        After every execution we want to prevent the user from changing something.
        So, disable the layout by greying it out

        :param bool:
        :return:
        """
        self.get_widget().setDisabled(bool)

    def setProgressBar(self, progressBar):
        """
        This function makes it possible to reference the progress bar
        in MainWindow

        :param progressBar:
        :return:
        """
        self.progressBar = progressBar

    def checkMinAndMax(self):
        """
        Go through the entire UI and set the maximums and minimums of each widget

        :return:
        """
        for name, obj in inspect.getmembers(self):
            if isinstance(obj, QSpinBox):
                obj.setMaximum(999999)

            if isinstance(obj, QDoubleSpinBox):
                obj.setDecimals(7)

    @staticmethod
    def getChangedValues(input_dictionary, algorithm):
        """
        Check symmetrically if the values in the dictionary match with values in the algorithm
        If they don't, then we will want to record those changed values.

        Example input: getChangedValues(methodParameters, AirPLS())

        :param input_dictionary:
        :param algorithm:
        :return:
        """
        dic = {}
        for key in input_dictionary:
            if input_dictionary[key] != getattr(algorithm, key):  # key gives us a string
                dic.update({key: input_dictionary[key]})
        return dic

    @staticmethod
    def setComboBox(comboBox, keyValues):
        """
        Sets up the information inside comboBox widgets
        This function does not need to be overridden.

        :param comboBox: QtWidgets.QComboBox
        :param keyValues: []
        :return:
        """
        comboBox.clear()
        comboBox.setMaximumWidth(400)
        comboBox.addItems(keyValues)

    @staticmethod
    def changeComboListVars(obj, newchoices):
        """
        Function changes combo boxes
        This function does not need to be overridden.

        :param obj:
        :param newchoices:
        :return:
        """
        obj.clear()
        for i in newchoices:
            if isinstance(i, tuple):
                obj.addItem(i[1])
            elif isinstance(i, str):
                obj.addItem(i)

    @staticmethod
    def setListWidget(obj, choices):
        """
        Function changes lists
        This function does not need to be overridden

        :param obj:
        :param choices:
        :return:
        """
        obj.clear()
        for item in choices:
            obj.addItem(item)

    @staticmethod
    def defaultComboItem(obj, item):
        """
        Set the default selected item in a box.

        :param obj:
        :param item:
        :return:
        """
        obj.setCurrentIndex(obj.findText(str(item)))

    @staticmethod
    def list_amend(list_, count_, input_):
        """
        In some cases a list is never actually instantiated.
        To fix this, we want to first try and see if we can access a particular count
        If that doesn't work due to an IndexError then we'll just settle for appending

        :param list_:
        :param count_:
        :param input_:
        :return:
        """
        try:
            list_[count_] = input_
        except IndexError:
            list_.append(input_)



# -*- coding: utf-8 -*-

# Automatically generated - don't edit.
# Use `python setup.py build_ui` to update it.

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        self.gridLayout = QtWidgets.QGridLayout(Form)
        self.gridLayout.setObjectName("gridLayout")
        self.chooseDataLabel = QtWidgets.QLabel(Form)
        self.chooseDataLabel.setObjectName("chooseDataLabel")
        self.gridLayout.addWidget(self.chooseDataLabel, 0, 0, 1, 1)
        self.chooseDataComboBox = QtWidgets.QComboBox(Form)
        self.chooseDataComboBox.setObjectName("chooseDataComboBox")
        self.gridLayout.addWidget(self.chooseDataComboBox, 0, 1, 1, 1)
        self.refreshTablePushButton = QtWidgets.QPushButton(Form)
        self.refreshTablePushButton.setObjectName("refreshTablePushButton")
        self.gridLayout.addWidget(self.refreshTablePushButton, 2, 1, 1, 1)
        self.tableView = QtWidgets.QTableView(Form)
        self.tableView.setObjectName("tableView")
        self.gridLayout.addWidget(self.tableView, 4, 0, 1, 2)
        self.refreshDataPushButton = QtWidgets.QPushButton(Form)
        self.refreshDataPushButton.setObjectName("refreshDataPushButton")
        self.gridLayout.addWidget(self.refreshDataPushButton, 1, 1, 1, 1)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(("Form"))
        self.chooseDataLabel.setText(("Choose Data"))
        self.refreshTablePushButton.setText(("Refresh Table"))
        self.refreshDataPushButton.setText(("Refresh Data"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())




from PyQt5 import QtWidgets, QtCore
from sklearn.linear_model.omp import OrthogonalMatchingPursuit
from sklearn.linear_model.omp import OrthogonalMatchingPursuitCV

from point_spectra_gui.ui.cv_OMP import Ui_Form
from point_spectra_gui.util.Modules import Modules


class Ui_Form(Ui_Form, OrthogonalMatchingPursuit, OrthogonalMatchingPursuitCV, Modules):
    def setupUi(self, Form):
        super().setupUi(Form)
        self.checkMinAndMax()
        self.connectWidgets()

    def get_widget(self):
        return self.formGroupBox

    def setHidden(self, bool):
        self.get_widget().setHidden(bool)

    def connectWidgets(self):
        self.fit_intercept_list.setCurrentItem(
            self.fit_intercept_list.findItems(str(self.fit_intercept), QtCore.Qt.MatchExactly)[0])
        self.normalize_list.setCurrentItem(
            self.normalize_list.findItems(str(self.normalize), QtCore.Qt.MatchExactly)[0])

    def run(self):
        fit_intercept_items = [i.text() == 'True' for i in self.fit_intercept_list.selectedItems()]
        normalize_items = [i.text() == 'True' for i in self.normalize_list.selectedItems()]

        params = {'n_nonzero_coefs': [int(i) for i in self.n_coefs_lineedit.text().split(',')],
                  'fit_intercept': fit_intercept_items,
                  'normalize': normalize_items,
                  'precompute': ['auto']}
        modelkey = str(params)
        return params, modelkey


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())



class Modules:
    some_list = {}

    def setItem(self, name, item):
        self.some_list[name] = item


class someUI(Modules):
    index = -1

    def __init__(self):
        super().__init__()
        someUI.index += 1
        self.curr_count = "someUI" + someUI.index

    def setItem(self, _item):
        super().setItem(self.curr_count, _item)


class strat(Modules):
    index = -1

    def __init__(self):
        super().__init__()
        strat.index += 1
        self.curr_count = "strat" + someUI.index

    def setItem(self, _item):
        super().setItem(self.curr_count, _item)


f = someUI()
f.setItem('item')
f.setItem('item2')
g = someUI()
g.setItem('item3')
g.setItem('item4')
h = strat()
h.setItem('item5')
pass



from PyQt5 import QtWidgets
from sklearn.decomposition.pca import PCA
from point_spectra_gui.ui.cluster_Spectral import Ui_Form
from point_spectra_gui.util.Modules import Modules


class Ui_Form(Ui_Form, PCA, Modules):
    def setupUi(self, Form):
        super().setupUi(Form)
        self.checkMinAndMax()
        self.connectWidgets()

    def get_widget(self):
        return self.groupBox

    def setHidden(self, bool):
        self.get_widget().setHidden(bool)

    def connectWidgets(self):
        self.n_clust_spin.setValue(8)
        self.n_runs_spin.setValue(10)
        self.gamma_dspin.setValue(1.0)
        self.n_neighbors_spin.setValue(10)
        self.coef0_spin.setValue(1)
        self.hide_for_kernel(self.affinity_comboBox.currentText())
        self.affinity_comboBox.currentIndexChanged.connect(
            lambda: self.hide_for_kernel(self.affinity_comboBox.currentText()))

    def hide_options(self, hide_list):
        self.gamma_dspin.setHidden(hide_list['gamma'])
        self.gamma_label.setHidden(hide_list['gamma'])
        self.n_neighbors_spin.setHidden(hide_list['n_neighbors'])
        self.n_neighbors_label.setHidden(hide_list['n_neighbors'])
        self.coef0_spin.setHidden(hide_list['coef0'])
        self.coef0_label.setHidden(hide_list['coef0'])
        self.degree_label.setHidden(hide_list['degree'])
        self.degree_spin.setHidden(hide_list['degree'])

    def hide_for_kernel(self, kernel):
        hide_list = {'gamma': True, 'n_neighbors': True, 'coef0': True, 'degree': True}
        if kernel == 'Radial Basis Function':
            hide_list['gamma'] = False
        if kernel == 'Nearest Neighbors':
            hide_list['n_neighbors'] = False
        if kernel == 'Sigmoid':
            hide_list['coef0'] = False
        if kernel == 'Polynomial':
            hide_list['degree'] = False
            hide_list['coef0'] = False
        self.hide_options(hide_list)

    def run(self):
        affinity = self.affinity_comboBox.currentText()
        if affinity == 'Radial Basis Function':
            kernel = 'rbf'
        if affinity == 'Nearest Neighbors':
            kernel = 'nearest_neighbors'
        if affinity == 'Sigmoid':
            kernel = 'sigmoid'
        if affinity == 'Polynomial':
            kernel = 'polynomial'
        if affinity == 'Linear':
            kernel = 'linear'
        if affinity == 'Cosine':
            kernel = 'cosine'

        params = {
            'n_clusters': self.n_clust_spin.value(),
            'n_init': self.n_runs_spin.value(),
            'affinity': kernel,
            'gamma': self.gamma_dspin.value(),
            'n_neighbors': self.n_neighbors_spin.value(),
            'degree': self.degree_spin.value(),
            'coef0': self.coef0_spin.value(),
            'n_jobs': -2} #use all but one cpu in parallel
        params_key = str(params)
        return params, params_key


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())



# -*- coding: utf-8 -*-

# Automatically generated - don't edit.
# Use `python setup.py build_ui` to update it.

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        self.verticalLayout = QtWidgets.QVBoxLayout(Form)
        self.verticalLayout.setObjectName("verticalLayout")
        self.groupBox = QtWidgets.QGroupBox(Form)
        self.groupBox.setObjectName("groupBox")
        self.gridLayout = QtWidgets.QGridLayout(self.groupBox)
        self.gridLayout.setObjectName("gridLayout")
        self.retorePushButton = QtWidgets.QPushButton(self.groupBox)
        self.retorePushButton.setMaximumSize(QtCore.QSize(30, 16777215))
        self.retorePushButton.setObjectName("retorePushButton")
        self.gridLayout.addWidget(self.retorePushButton, 0, 1, 1, 1)
        self.restoreLineEdit = QtWidgets.QLineEdit(self.groupBox)
        self.restoreLineEdit.setFrame(True)
        self.restoreLineEdit.setReadOnly(True)
        self.restoreLineEdit.setObjectName("restoreLineEdit")
        self.gridLayout.addWidget(self.restoreLineEdit, 0, 0, 1, 1)
        self.restoreTextBrowser = QtWidgets.QTextBrowser(self.groupBox)
        self.restoreTextBrowser.setObjectName("restoreTextBrowser")
        self.gridLayout.addWidget(self.restoreTextBrowser, 2, 0, 1, 1)
        self.detailsPushButton = QtWidgets.QPushButton(self.groupBox)
        self.detailsPushButton.setObjectName("detailsPushButton")
        self.gridLayout.addWidget(self.detailsPushButton, 1, 0, 1, 1)
        self.verticalLayout.addWidget(self.groupBox)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(("Form"))
        self.groupBox.setTitle(("Restore a Trained Model"))
        self.retorePushButton.setText(("..."))
        self.detailsPushButton.setText(("Details"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())




import numpy as np
from PyQt5 import QtWidgets
from point_spectra_gui.util.spectral_data import spectral_data
from point_spectra_gui.ui.RemoveRows import Ui_Form
from point_spectra_gui.util.Modules import Modules


class remove_operation:
    def __init__(self, colname, operator, value, logic=None, hidden=None):
        self.colname = colname
        self.operator = operator
        self.value = value
        self.logic = logic
        self.hidden = hidden
        if hidden is not None:
            self.hidden.setHidden(True)
            self.hidden.stateChanged.connect(self.Hidden)

    def Hidden(self):
        if self.hidden.isChecked():
            self.colname.setHidden(True)
            self.operator.setHidden(True)
            self.value.setHidden(True)
            try:
                self.logic.setHidden(True)
            except:
                pass

        else:
            self.colname.setHidden(False)
            self.operator.setHidden(False)
            self.value.setHidden(False)
            try:
                self.logic.setHidden(False)
            except:
                pass

    def GetValues(self):
        try:
            return {'column': self.colname.currentText(), 'operator': self.operator.currentText(),
                    'value': self.value.currentText().split(' : ')[0], 'logic': self.logic.currentText()}
        except:
            return {'column': self.colname.currentText(), 'operator': self.operator.currentText(),
                    'value': self.value.currentText().split(' : ')[0]}


class RemoveRows(Ui_Form, Modules):
    def setupUi(self, Form):
        super().setupUi(Form)
        self.setup_remove_operations()
        Modules.setupUi(self, Form)

    def setup_remove_operations(self):
        self.operations = [remove_operation(self.colName_1, self.operator_1, self.value_1, logic = self.logic_1),
                           remove_operation(self.colName_2, self.operator_2, self.value_2, logic=self.logic_2, hidden=self.hidden_2),
                           remove_operation(self.colName_3, self.operator_3, self.value_3, logic=self.logic_3, hidden=self.hidden_3),
                           remove_operation(self.colName_4, self.operator_4, self.value_4, logic=self.logic_4, hidden=self.hidden_4),
                           remove_operation(self.colName_5, self.operator_5, self.value_5, hidden=self.hidden_5)]
        for i in self.operations:
            try:
                i.hidden.setChecked(True)
            except:
                pass
            i.colname.currentIndexChanged.connect(lambda: self.update_vals())

    def get_widget(self):
        return self.groupBox

    def connectWidgets(self):
        self.setComboBox(self.chooseData, self.datakeys)
        self.chooseData.currentIndexChanged.connect(lambda: self.update_cols())
        self.update_cols()
        self.connect_logic()

    def update_cols(self):
        for i in self.operations:
            self.setComboBox(i.colname, self.get_colname_choices())
            self.update_vals()

    def update_vals(self):
        for i in self.operations:
            self.setComboBox(i.value, self.get_rowval_choices(i.colname.currentText()))

    def connect_logic(self):
        for i in self.operations:
            try:
                i.logic.currentIndexChanged.connect(lambda: self.hide_operations())
            except:
                pass

    def hide_operations(self):
        for i in range(len(self.operations) - 1):
            try:
                if self.operations[i].logic.currentText() == 'and':
                    self.operations[i + 1].hidden.setChecked(False)
                else:
                    self.operations[i + 1].hidden.setChecked(True)

                if self.operations[i + 1].logic.currentText() == 'and':
                    self.operations[i].logic.setEnabled(False)
                else:
                    self.operations[i].logic.setEnabled(True)
            except:
                pass

    def run(self):
        match_vectors = []
        logic_list = []
        datakey = self.chooseData.currentText()
        for i in self.operations:
            values_tmp = i.GetValues()
            if i.hidden == None:
                match_vectors.append(self.evaluate_operation(datakey, values_tmp))
                logic_list.append(values_tmp['logic'])
            else:
                if i.hidden.isChecked() == False:
                    match_vectors.append(self.evaluate_operation(datakey, values_tmp))
                    logic_list.append(values_tmp['logic'])

        match_combined = np.all(match_vectors, axis=0)
        print(self.data[datakey].df.shape)
        self.data[datakey] = spectral_data(self.data[datakey].df.ix[~match_combined])
        print(self.data[datakey].df.shape)

    def evaluate_operation(self, datakey, operation_values):
        colname = operation_values['column']
        value = operation_values['value']
        operator = operation_values['operator']

        vars_level0 = self.data[datakey].df.columns.get_level_values(0)
        vars_level1 = self.data[datakey].df.columns.get_level_values(1)
        vars_level1 = list(vars_level1[vars_level0 != 'wvl'])
        vars_level0 = list(vars_level0[vars_level0 != 'wvl'])
        colname = (vars_level0[vars_level1.index(colname)], colname)
        coldata = np.array([str(i) for i in self.data[datakey].df[colname]])
        #
        # if value == 'Null':
        #     self.data[datakey] = spectral_data(self.data[datakey].df.ix[-self.data[datakey].df[colname].isnull()])
        # else:
        #     # find where the values in the specified column match the value to be removed

        if operator == '=':
            match = coldata == value
        if operator == '>':
            match = coldata > value
        if operator == '<':
            match = coldata < value
        if operator == '<=':
            match = coldata <= value
        if operator == '>=':
            match = coldata >= value

        return match
        #     # keep everything except where match is true
        #     self.data[datakey] = spectral_data(self.data[datakey].df.ix[~match])
        # print(self.data[datakey].df.shape)

    def get_colname_choices(self):
        try:
            self.vars_level0 = self.data[self.chooseData.currentText()].df.columns.get_level_values(0)
            self.vars_level1 = self.data[self.chooseData.currentText()].df.columns.get_level_values(1)
            self.vars_level1 = list(
                self.vars_level1[np.logical_and(self.vars_level0 != 'wvl', self.vars_level0 != 'masked')])
            self.vars_level0 = list(
                self.vars_level0[np.logical_and(self.vars_level0 != 'wvl', self.vars_level0 != 'masked')])

            colnamechoices = self.vars_level1

        except:
            try:
                colnamechoices = self.data[self.chooseData.currentText()].columns.values
            except:
                colnamechoices = []
        colnamechoices = [i for i in colnamechoices if not 'Unnamed' in str(i)]  # remove unnamed columns from choices
        return colnamechoices

    def get_rowval_choices(self, colname):
        try:
            colname = (self.vars_level0[self.vars_level1.index(colname)], colname)
            choices = self.data[self.chooseData.currentText()].df[colname]
            # choices = choices[~np.isnan(choices)]
            # nchoices2 = choices.size
            nchoice = []
            choices = np.sort(choices)
            choices = [str(i) for i in choices]

            for choice in choices:
                if not choice + ' : ' + str(choices.count(choice)) in nchoice:
                    nchoice.append(choice + ' : ' + str(choices.count(choice)))
            choices = nchoice
        except:
            choices = ['-']
        return choices


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)

    Form = QtWidgets.QWidget()
    ui = RemoveRows()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())



# -*- coding: utf-8 -*-

# Automatically generated - don't edit.
# Use `python setup.py build_ui` to update it.

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Ignored)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Form.sizePolicy().hasHeightForWidth())
        Form.setSizePolicy(sizePolicy)
        self.verticalLayout = QtWidgets.QVBoxLayout(Form)
        self.verticalLayout.setObjectName("verticalLayout")
        self.formGroupBox = QtWidgets.QGroupBox(Form)
        self.formGroupBox.setObjectName("formGroupBox")
        self.formLayout = QtWidgets.QFormLayout(self.formGroupBox)
        self.formLayout.setFieldGrowthPolicy(QtWidgets.QFormLayout.AllNonFixedFieldsGrow)
        self.formLayout.setObjectName("formLayout")
        self.numOfIterationsLabel = QtWidgets.QLabel(self.formGroupBox)
        self.numOfIterationsLabel.setObjectName("numOfIterationsLabel")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.numOfIterationsLabel)
        self.numOfIterationsLineEdit = QtWidgets.QLineEdit(self.formGroupBox)
        self.numOfIterationsLineEdit.setProperty("maximum", 999999999)
        self.numOfIterationsLineEdit.setProperty("value", 300)
        self.numOfIterationsLineEdit.setObjectName("numOfIterationsLineEdit")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.numOfIterationsLineEdit)
        self.toleranceLabel = QtWidgets.QLabel(self.formGroupBox)
        self.toleranceLabel.setObjectName("toleranceLabel")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.toleranceLabel)
        self.toleranceLineEdit = QtWidgets.QLineEdit(self.formGroupBox)
        self.toleranceLineEdit.setProperty("decimals", 8)
        self.toleranceLineEdit.setProperty("singleStep", 0.001)
        self.toleranceLineEdit.setProperty("value", 0.001)
        self.toleranceLineEdit.setObjectName("toleranceLineEdit")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.toleranceLineEdit)
        self.alpha1Label = QtWidgets.QLabel(self.formGroupBox)
        self.alpha1Label.setObjectName("alpha1Label")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.alpha1Label)
        self.alpha1LineEdit = QtWidgets.QLineEdit(self.formGroupBox)
        self.alpha1LineEdit.setProperty("decimals", 5)
        self.alpha1LineEdit.setProperty("singleStep", 0.001)
        self.alpha1LineEdit.setProperty("value", 0.001)
        self.alpha1LineEdit.setObjectName("alpha1LineEdit")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.alpha1LineEdit)
        self.alpha2Label = QtWidgets.QLabel(self.formGroupBox)
        self.alpha2Label.setObjectName("alpha2Label")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.alpha2Label)
        self.alpha2LineEdit = QtWidgets.QLineEdit(self.formGroupBox)
        self.alpha2LineEdit.setProperty("decimals", 8)
        self.alpha2LineEdit.setProperty("singleStep", 1e-06)
        self.alpha2LineEdit.setProperty("value", 1e-06)
        self.alpha2LineEdit.setObjectName("alpha2LineEdit")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.alpha2LineEdit)
        self.lambdaLabel = QtWidgets.QLabel(self.formGroupBox)
        self.lambdaLabel.setObjectName("lambdaLabel")
        self.formLayout.setWidget(4, QtWidgets.QFormLayout.LabelRole, self.lambdaLabel)
        self.lambdaLineEdit = QtWidgets.QLineEdit(self.formGroupBox)
        self.lambdaLineEdit.setProperty("decimals", 8)
        self.lambdaLineEdit.setProperty("singleStep", 1e-06)
        self.lambdaLineEdit.setProperty("value", 1e-06)
        self.lambdaLineEdit.setObjectName("lambdaLineEdit")
        self.formLayout.setWidget(4, QtWidgets.QFormLayout.FieldRole, self.lambdaLineEdit)
        self.lambdaLabel_2 = QtWidgets.QLabel(self.formGroupBox)
        self.lambdaLabel_2.setObjectName("lambdaLabel_2")
        self.formLayout.setWidget(5, QtWidgets.QFormLayout.LabelRole, self.lambdaLabel_2)
        self.lambdaLineEdit_2 = QtWidgets.QLineEdit(self.formGroupBox)
        self.lambdaLineEdit_2.setProperty("decimals", 8)
        self.lambdaLineEdit_2.setProperty("singleStep", 1e-06)
        self.lambdaLineEdit_2.setProperty("value", 1e-06)
        self.lambdaLineEdit_2.setObjectName("lambdaLineEdit_2")
        self.formLayout.setWidget(5, QtWidgets.QFormLayout.FieldRole, self.lambdaLineEdit_2)
        self.thresholdLambdaLabel = QtWidgets.QLabel(self.formGroupBox)
        self.thresholdLambdaLabel.setObjectName("thresholdLambdaLabel")
        self.formLayout.setWidget(6, QtWidgets.QFormLayout.LabelRole, self.thresholdLambdaLabel)
        self.thresholdLambdaLineEdit = QtWidgets.QLineEdit(self.formGroupBox)
        self.thresholdLambdaLineEdit.setProperty("maximum", 999999999)
        self.thresholdLambdaLineEdit.setProperty("value", 100000)
        self.thresholdLambdaLineEdit.setObjectName("thresholdLambdaLineEdit")
        self.formLayout.setWidget(6, QtWidgets.QFormLayout.FieldRole, self.thresholdLambdaLineEdit)
        self.fitInterceptLabel = QtWidgets.QLabel(self.formGroupBox)
        self.fitInterceptLabel.setObjectName("fitInterceptLabel")
        self.formLayout.setWidget(7, QtWidgets.QFormLayout.LabelRole, self.fitInterceptLabel)
        self.fitIntercept_list = QtWidgets.QListWidget(self.formGroupBox)
        self.fitIntercept_list.setMaximumSize(QtCore.QSize(16777215, 50))
        self.fitIntercept_list.setSelectionMode(QtWidgets.QAbstractItemView.MultiSelection)
        self.fitIntercept_list.setObjectName("fitIntercept_list")
        item = QtWidgets.QListWidgetItem()
        self.fitIntercept_list.addItem(item)
        item = QtWidgets.QListWidgetItem()
        self.fitIntercept_list.addItem(item)
        self.formLayout.setWidget(7, QtWidgets.QFormLayout.FieldRole, self.fitIntercept_list)
        self.normalizeLabel = QtWidgets.QLabel(self.formGroupBox)
        self.normalizeLabel.setObjectName("normalizeLabel")
        self.formLayout.setWidget(8, QtWidgets.QFormLayout.LabelRole, self.normalizeLabel)
        self.normalize_list = QtWidgets.QListWidget(self.formGroupBox)
        self.normalize_list.setMaximumSize(QtCore.QSize(16777215, 50))
        self.normalize_list.setSelectionMode(QtWidgets.QAbstractItemView.MultiSelection)
        self.normalize_list.setObjectName("normalize_list")
        item = QtWidgets.QListWidgetItem()
        self.normalize_list.addItem(item)
        item = QtWidgets.QListWidgetItem()
        self.normalize_list.addItem(item)
        self.formLayout.setWidget(8, QtWidgets.QFormLayout.FieldRole, self.normalize_list)
        self.verticalLayout.addWidget(self.formGroupBox)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)
        Form.setTabOrder(self.numOfIterationsLineEdit, self.toleranceLineEdit)
        Form.setTabOrder(self.toleranceLineEdit, self.alpha1LineEdit)
        Form.setTabOrder(self.alpha1LineEdit, self.alpha2LineEdit)
        Form.setTabOrder(self.alpha2LineEdit, self.lambdaLineEdit)
        Form.setTabOrder(self.lambdaLineEdit, self.lambdaLineEdit_2)
        Form.setTabOrder(self.lambdaLineEdit_2, self.thresholdLambdaLineEdit)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(("Form"))
        self.formGroupBox.setToolTip(("<html><head/><body><p>Fit regression model with Bayesian Ridge Regression.</p><p>See Bayesian Ridge Regression for more information on the regressor.</p><p>Compared to the OLS (ordinary least squares) estimator, the coefficient weights are slightly shifted toward zeros, which stabilises them.</p><p>The histogram of the estimated weights is very peaked, as a sparsity-inducing prior is implied on the weights.</p><p>The estimation of the model is done by iteratively maximizing the marginal log-likelihood of the observations.</p></body></html>"))
        self.formGroupBox.setTitle(("ARD"))
        self.numOfIterationsLabel.setText(("num of iterations"))
        self.numOfIterationsLineEdit.setText(("300"))
        self.toleranceLabel.setText(("Tolerance"))
        self.toleranceLineEdit.setText(("0.001"))
        self.alpha1Label.setText(("Alpha 1"))
        self.alpha1LineEdit.setText(("0.000001"))
        self.alpha2Label.setText(("Alpha 2"))
        self.alpha2LineEdit.setText(("0.000001"))
        self.lambdaLabel.setText(("Lambda 1"))
        self.lambdaLineEdit.setText(("0.000001"))
        self.lambdaLabel_2.setText(("Lambda 2"))
        self.lambdaLineEdit_2.setText(("0.000001"))
        self.thresholdLambdaLabel.setText(("Threshold Lambda"))
        self.thresholdLambdaLineEdit.setText(("10000"))
        self.fitInterceptLabel.setText(("Fit Intercept"))
        __sortingEnabled = self.fitIntercept_list.isSortingEnabled()
        self.fitIntercept_list.setSortingEnabled(False)
        item = self.fitIntercept_list.item(0)
        item.setText(("True"))
        item = self.fitIntercept_list.item(1)
        item.setText(("False"))
        self.fitIntercept_list.setSortingEnabled(__sortingEnabled)
        self.normalizeLabel.setText(("Normalize"))
        __sortingEnabled = self.normalize_list.isSortingEnabled()
        self.normalize_list.setSortingEnabled(False)
        item = self.normalize_list.item(0)
        item.setText(("True"))
        item = self.normalize_list.item(1)
        item.setText(("False"))
        self.normalize_list.setSortingEnabled(__sortingEnabled)


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())




from PyQt5 import QtWidgets
from sklearn.manifold.t_sne import TSNE
from point_spectra_gui.ui.dimred_tSNE import Ui_Form
from point_spectra_gui.util.Modules import Modules


class Ui_Form(Ui_Form, TSNE, Modules):
    def setupUi(self, Form):
        super().setupUi(Form)
        self.checkMinAndMax()
        self.connectWidgets()

    def get_widget(self):
        return self.groupBox

    def setHidden(self, bool):
        self.get_widget().setHidden(bool)

    def connectWidgets(self):
        self.nc_spin.setValue(self.n_components)
        self.learning_spin.setValue(self.learning_rate)
        self.n_iter_spin.setValue(self.n_iter)
        self.no_progress_spin.setValue(300)
        self.perplexity_spin.setValue(50)

    def run(self):
        params = {
            'n_components': self.nc_spin.value(),
            'learning_rate': self.learning_spin.value(),
            'n_iter': self.n_iter_spin.value(),
            'n_iter_without_progress': self.no_progress_spin.value(),
            'perplexity': self.perplexity_spin.value()
        }

        params_key = str(params)
        return params, params_key


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())



from PyQt5 import QtWidgets, QtCore
from sklearn.linear_model import BayesianRidge

from point_spectra_gui.ui.cv_BayesianRidge import Ui_Form
from point_spectra_gui.util.Modules import Modules


class Ui_Form(Ui_Form, BayesianRidge, Modules):
    def setupUi(self, Form):
        super().setupUi(Form)
        self.checkMinAndMax()
        self.connectWidgets()

    def get_widget(self):
        return self.formGroupBox

    def setHidden(self, bool):
        self.get_widget().setHidden(bool)

    def connectWidgets(self):
        self.numOfIterationsLineEdit.setText(str(self.n_iter))
        self.toleranceLineEdit.setText(str(self.tol))
        self.alpha1LineEdit.setText(str(self.alpha_1))
        self.alpha2LineEdit.setText(str(self.alpha_2))
        self.lambdaLineEdit.setText(str(self.lambda_1))
        self.lambda2LineEdit.setText(str(self.lambda_2))
        self.fitIntercept_List.setCurrentItem(
            self.fitIntercept_List.findItems(str(self.fit_intercept), QtCore.Qt.MatchExactly)[0])
        self.normalize_List.setCurrentItem(
            self.normalize_List.findItems(str(self.normalize), QtCore.Qt.MatchExactly)[0])

    def run(self):
        fit_intercept_items = [i.text() == 'True' for i in self.fitIntercept_List.selectedItems()]
        normalize_items = [i.text() == 'True' for i in self.normalize_List.selectedItems()]

        params = {
            'n_iter': [int(i) for i in self.numOfIterationsLineEdit.text().split(',')],
            'tol': [float(i) for i in self.toleranceLineEdit.text().split(',')],
            'alpha_1': [float(i) for i in self.alpha1LineEdit.text().split(',')],
            'alpha_2': [float(i) for i in self.alpha2LineEdit.text().split(',')],
            'lambda_1': [float(i) for i in self.lambdaLineEdit.text().split(',')],
            'lambda_2': [float(i) for i in self.lambda2LineEdit.text().split(',')],
            'compute_score': [False],
            'fit_intercept': fit_intercept_items,
            'normalize': normalize_items,
            'copy_X': [True],
            'verbose': [True]}
        modelkey = str(params)
        return params, modelkey


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())



# -*- coding: utf-8 -*-

# Automatically generated - don't edit.
# Use `python setup.py build_ui` to update it.

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Ignored)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Form.sizePolicy().hasHeightForWidth())
        Form.setSizePolicy(sizePolicy)
        self.verticalLayout = QtWidgets.QVBoxLayout(Form)
        self.verticalLayout.setObjectName("verticalLayout")
        self.elasticNetGroupBox = QtWidgets.QGroupBox(Form)
        self.elasticNetGroupBox.setTitle("")
        self.elasticNetGroupBox.setObjectName("elasticNetGroupBox")
        self.ElasticNet = QtWidgets.QFormLayout(self.elasticNetGroupBox)
        self.ElasticNet.setFieldGrowthPolicy(QtWidgets.QFormLayout.AllNonFixedFieldsGrow)
        self.ElasticNet.setObjectName("ElasticNet")
        self.minalpha_label = QtWidgets.QLabel(self.elasticNetGroupBox)
        self.minalpha_label.setObjectName("minalpha_label")
        self.ElasticNet.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.minalpha_label)
        self.minalpha_spin = QtWidgets.QDoubleSpinBox(self.elasticNetGroupBox)
        self.minalpha_spin.setDecimals(20)
        self.minalpha_spin.setMaximum(999999999.0)
        self.minalpha_spin.setObjectName("minalpha_spin")
        self.ElasticNet.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.minalpha_spin)
        self.maxalpha_label = QtWidgets.QLabel(self.elasticNetGroupBox)
        self.maxalpha_label.setObjectName("maxalpha_label")
        self.ElasticNet.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.maxalpha_label)
        self.maxalpha_spin = QtWidgets.QDoubleSpinBox(self.elasticNetGroupBox)
        self.maxalpha_spin.setDecimals(20)
        self.maxalpha_spin.setMaximum(999999999.0)
        self.maxalpha_spin.setObjectName("maxalpha_spin")
        self.ElasticNet.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.maxalpha_spin)
        self.nalpha_label = QtWidgets.QLabel(self.elasticNetGroupBox)
        self.nalpha_label.setToolTip("")
        self.nalpha_label.setObjectName("nalpha_label")
        self.ElasticNet.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.nalpha_label)
        self.nalpha_spin = QtWidgets.QSpinBox(self.elasticNetGroupBox)
        self.nalpha_spin.setToolTip("")
        self.nalpha_spin.setMaximum(999999999)
        self.nalpha_spin.setObjectName("nalpha_spin")
        self.ElasticNet.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.nalpha_spin)
        self.enl1_ratioLabel = QtWidgets.QLabel(self.elasticNetGroupBox)
        self.enl1_ratioLabel.setObjectName("enl1_ratioLabel")
        self.ElasticNet.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.enl1_ratioLabel)
        self.enl1_ratioLineEdit = QtWidgets.QLineEdit(self.elasticNetGroupBox)
        self.enl1_ratioLineEdit.setObjectName("enl1_ratioLineEdit")
        self.ElasticNet.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.enl1_ratioLineEdit)
        self.enmax_iterLabel = QtWidgets.QLabel(self.elasticNetGroupBox)
        self.enmax_iterLabel.setObjectName("enmax_iterLabel")
        self.ElasticNet.setWidget(5, QtWidgets.QFormLayout.LabelRole, self.enmax_iterLabel)
        self.enmax_iterLineEdit = QtWidgets.QLineEdit(self.elasticNetGroupBox)
        self.enmax_iterLineEdit.setObjectName("enmax_iterLineEdit")
        self.ElasticNet.setWidget(5, QtWidgets.QFormLayout.FieldRole, self.enmax_iterLineEdit)
        self.entolLabel = QtWidgets.QLabel(self.elasticNetGroupBox)
        self.entolLabel.setObjectName("entolLabel")
        self.ElasticNet.setWidget(6, QtWidgets.QFormLayout.LabelRole, self.entolLabel)
        self.entolLineEdit = QtWidgets.QLineEdit(self.elasticNetGroupBox)
        self.entolLineEdit.setObjectName("entolLineEdit")
        self.ElasticNet.setWidget(6, QtWidgets.QFormLayout.FieldRole, self.entolLineEdit)
        self.enpositiveLabel = QtWidgets.QLabel(self.elasticNetGroupBox)
        self.enpositiveLabel.setObjectName("enpositiveLabel")
        self.ElasticNet.setWidget(8, QtWidgets.QFormLayout.LabelRole, self.enpositiveLabel)
        self.enpositive_list = QtWidgets.QListWidget(self.elasticNetGroupBox)
        self.enpositive_list.setMaximumSize(QtCore.QSize(16777215, 50))
        self.enpositive_list.setSelectionMode(QtWidgets.QAbstractItemView.MultiSelection)
        self.enpositive_list.setObjectName("enpositive_list")
        item = QtWidgets.QListWidgetItem()
        self.enpositive_list.addItem(item)
        item = QtWidgets.QListWidgetItem()
        self.enpositive_list.addItem(item)
        self.ElasticNet.setWidget(8, QtWidgets.QFormLayout.FieldRole, self.enpositive_list)
        self.enfit_interceptLabel = QtWidgets.QLabel(self.elasticNetGroupBox)
        self.enfit_interceptLabel.setObjectName("enfit_interceptLabel")
        self.ElasticNet.setWidget(7, QtWidgets.QFormLayout.LabelRole, self.enfit_interceptLabel)
        self.enfit_intercept_list = QtWidgets.QListWidget(self.elasticNetGroupBox)
        self.enfit_intercept_list.setMaximumSize(QtCore.QSize(16777215, 50))
        self.enfit_intercept_list.setSelectionMode(QtWidgets.QAbstractItemView.MultiSelection)
        self.enfit_intercept_list.setObjectName("enfit_intercept_list")
        item = QtWidgets.QListWidgetItem()
        self.enfit_intercept_list.addItem(item)
        item = QtWidgets.QListWidgetItem()
        self.enfit_intercept_list.addItem(item)
        self.ElasticNet.setWidget(7, QtWidgets.QFormLayout.FieldRole, self.enfit_intercept_list)
        self.verticalLayout.addWidget(self.elasticNetGroupBox)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(("Form"))
        self.minalpha_label.setText(("Min Alpha"))
        self.maxalpha_label.setText(("Max Alpha"))
        self.nalpha_label.setText(("# of Alphas"))
        self.enl1_ratioLabel.setText(("L1 ratio"))
        self.enl1_ratioLineEdit.setText((".1, .5, .7, .9, .95, .99, 1"))
        self.enmax_iterLabel.setText(("Max. # of iterations"))
        self.enmax_iterLineEdit.setText(("1000"))
        self.entolLabel.setText(("Tolerance"))
        self.entolLineEdit.setText(("0.0001"))
        self.enpositiveLabel.setText(("Force Positive Coefficients"))
        __sortingEnabled = self.enpositive_list.isSortingEnabled()
        self.enpositive_list.setSortingEnabled(False)
        item = self.enpositive_list.item(0)
        item.setText(("True"))
        item = self.enpositive_list.item(1)
        item.setText(("False"))
        self.enpositive_list.setSortingEnabled(__sortingEnabled)
        self.enfit_interceptLabel.setText(("Fit Intercept"))
        __sortingEnabled = self.enfit_intercept_list.isSortingEnabled()
        self.enfit_intercept_list.setSortingEnabled(False)
        item = self.enfit_intercept_list.item(0)
        item.setText(("True"))
        item = self.enfit_intercept_list.item(1)
        item.setText(("False"))
        self.enfit_intercept_list.setSortingEnabled(__sortingEnabled)


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())




# -*- coding: utf-8 -*-

# Automatically generated - don't edit.
# Use `python setup.py build_ui` to update it.

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Ignored)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Form.sizePolicy().hasHeightForWidth())
        Form.setSizePolicy(sizePolicy)
        self.verticalLayout = QtWidgets.QVBoxLayout(Form)
        self.verticalLayout.setObjectName("verticalLayout")
        self.groupBox = QtWidgets.QGroupBox(Form)
        self.groupBox.setObjectName("groupBox")
        self.formLayout = QtWidgets.QFormLayout(self.groupBox)
        self.formLayout.setFieldGrowthPolicy(QtWidgets.QFormLayout.AllNonFixedFieldsGrow)
        self.formLayout.setObjectName("formLayout")
        self.nc_label = QtWidgets.QLabel(self.groupBox)
        self.nc_label.setObjectName("nc_label")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.nc_label)
        self.nc_spin = QtWidgets.QSpinBox(self.groupBox)
        self.nc_spin.setObjectName("nc_spin")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.nc_spin)
        self.learning_label = QtWidgets.QLabel(self.groupBox)
        self.learning_label.setObjectName("learning_label")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.learning_label)
        self.learning_spin = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.learning_spin.setMinimum(10.0)
        self.learning_spin.setMaximum(2000.0)
        self.learning_spin.setProperty("value", 200.0)
        self.learning_spin.setObjectName("learning_spin")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.learning_spin)
        self.n_iter_label = QtWidgets.QLabel(self.groupBox)
        self.n_iter_label.setObjectName("n_iter_label")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.n_iter_label)
        self.n_iter_spin = QtWidgets.QSpinBox(self.groupBox)
        self.n_iter_spin.setMinimum(250)
        self.n_iter_spin.setMaximum(999999999)
        self.n_iter_spin.setProperty("value", 1000)
        self.n_iter_spin.setObjectName("n_iter_spin")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.n_iter_spin)
        self.no_progress_label = QtWidgets.QLabel(self.groupBox)
        self.no_progress_label.setObjectName("no_progress_label")
        self.formLayout.setWidget(4, QtWidgets.QFormLayout.LabelRole, self.no_progress_label)
        self.no_progress_spin = QtWidgets.QSpinBox(self.groupBox)
        self.no_progress_spin.setMinimum(50)
        self.no_progress_spin.setMaximum(999999999)
        self.no_progress_spin.setSingleStep(50)
        self.no_progress_spin.setProperty("value", 300)
        self.no_progress_spin.setObjectName("no_progress_spin")
        self.formLayout.setWidget(4, QtWidgets.QFormLayout.FieldRole, self.no_progress_spin)
        self.perplexity = QtWidgets.QLabel(self.groupBox)
        self.perplexity.setObjectName("perplexity")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.perplexity)
        self.perplexity_spin = QtWidgets.QSpinBox(self.groupBox)
        self.perplexity_spin.setMaximum(10000)
        self.perplexity_spin.setObjectName("perplexity_spin")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.perplexity_spin)
        self.verticalLayout.addWidget(self.groupBox)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(("Form"))
        self.nc_label.setText(("# of components"))
        self.learning_label.setText(("Learning Rate"))
        self.n_iter_label.setText(("# of iterations"))
        self.no_progress_label.setText(("# with no progress"))
        self.perplexity.setText(("Perplexity"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())




# -*- coding: utf-8 -*-

# Automatically generated - don't edit.
# Use `python setup.py build_ui` to update it.

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Ignored)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Form.sizePolicy().hasHeightForWidth())
        Form.setSizePolicy(sizePolicy)
        self.verticalLayout = QtWidgets.QVBoxLayout(Form)
        self.verticalLayout.setObjectName("verticalLayout")
        self.groupBox = QtWidgets.QGroupBox(Form)
        self.groupBox.setObjectName("groupBox")
        self.formLayout = QtWidgets.QFormLayout(self.groupBox)
        self.formLayout.setFieldGrowthPolicy(QtWidgets.QFormLayout.AllNonFixedFieldsGrow)
        self.formLayout.setObjectName("formLayout")
        self.minalphaLabel = QtWidgets.QLabel(self.groupBox)
        self.minalphaLabel.setObjectName("minalphaLabel")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.minalphaLabel)
        self.minalpha_spin = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.minalpha_spin.setDecimals(20)
        self.minalpha_spin.setMaximum(1000000000.0)
        self.minalpha_spin.setObjectName("minalpha_spin")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.minalpha_spin)
        self.maxalpha_label = QtWidgets.QLabel(self.groupBox)
        self.maxalpha_label.setObjectName("maxalpha_label")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.maxalpha_label)
        self.maxalpha_spin = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.maxalpha_spin.setDecimals(20)
        self.maxalpha_spin.setMaximum(1000000000.0)
        self.maxalpha_spin.setObjectName("maxalpha_spin")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.maxalpha_spin)
        self.nalphas_label = QtWidgets.QLabel(self.groupBox)
        self.nalphas_label.setToolTip("")
        self.nalphas_label.setObjectName("nalphas_label")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.nalphas_label)
        self.nalphas_spin = QtWidgets.QSpinBox(self.groupBox)
        self.nalphas_spin.setToolTip("")
        self.nalphas_spin.setObjectName("nalphas_spin")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.nalphas_spin)
        self.maxNumOfIterationsLabel = QtWidgets.QLabel(self.groupBox)
        self.maxNumOfIterationsLabel.setObjectName("maxNumOfIterationsLabel")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.maxNumOfIterationsLabel)
        self.maxNumOfIterationsLineEdit = QtWidgets.QLineEdit(self.groupBox)
        self.maxNumOfIterationsLineEdit.setProperty("maximum", 999999999)
        self.maxNumOfIterationsLineEdit.setProperty("value", 1000)
        self.maxNumOfIterationsLineEdit.setObjectName("maxNumOfIterationsLineEdit")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.maxNumOfIterationsLineEdit)
        self.toleranceLabel = QtWidgets.QLabel(self.groupBox)
        self.toleranceLabel.setObjectName("toleranceLabel")
        self.formLayout.setWidget(4, QtWidgets.QFormLayout.LabelRole, self.toleranceLabel)
        self.toleranceLineEdit = QtWidgets.QLineEdit(self.groupBox)
        self.toleranceLineEdit.setProperty("decimals", 5)
        self.toleranceLineEdit.setProperty("maximum", 999999999.0)
        self.toleranceLineEdit.setProperty("value", 0.0001)
        self.toleranceLineEdit.setObjectName("toleranceLineEdit")
        self.formLayout.setWidget(4, QtWidgets.QFormLayout.FieldRole, self.toleranceLineEdit)
        self.fitInterceptLabel = QtWidgets.QLabel(self.groupBox)
        self.fitInterceptLabel.setObjectName("fitInterceptLabel")
        self.formLayout.setWidget(5, QtWidgets.QFormLayout.LabelRole, self.fitInterceptLabel)
        self.fit_intercept_list = QtWidgets.QListWidget(self.groupBox)
        self.fit_intercept_list.setMaximumSize(QtCore.QSize(16777215, 50))
        self.fit_intercept_list.setSelectionMode(QtWidgets.QAbstractItemView.MultiSelection)
        self.fit_intercept_list.setObjectName("fit_intercept_list")
        item = QtWidgets.QListWidgetItem()
        self.fit_intercept_list.addItem(item)
        item = QtWidgets.QListWidgetItem()
        self.fit_intercept_list.addItem(item)
        self.formLayout.setWidget(5, QtWidgets.QFormLayout.FieldRole, self.fit_intercept_list)
        self.forcePositiveCoefficientsLabel = QtWidgets.QLabel(self.groupBox)
        self.forcePositiveCoefficientsLabel.setObjectName("forcePositiveCoefficientsLabel")
        self.formLayout.setWidget(6, QtWidgets.QFormLayout.LabelRole, self.forcePositiveCoefficientsLabel)
        self.forcePositive_list = QtWidgets.QListWidget(self.groupBox)
        self.forcePositive_list.setMaximumSize(QtCore.QSize(16777215, 50))
        self.forcePositive_list.setSelectionMode(QtWidgets.QAbstractItemView.MultiSelection)
        self.forcePositive_list.setObjectName("forcePositive_list")
        item = QtWidgets.QListWidgetItem()
        self.forcePositive_list.addItem(item)
        item = QtWidgets.QListWidgetItem()
        self.forcePositive_list.addItem(item)
        self.formLayout.setWidget(6, QtWidgets.QFormLayout.FieldRole, self.forcePositive_list)
        self.verticalLayout.addWidget(self.groupBox)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)
        Form.setTabOrder(self.maxNumOfIterationsLineEdit, self.toleranceLineEdit)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(("Form"))
        self.groupBox.setToolTip(("<html><head/><body><p>The <span style=\" font-weight:600;\">Lasso</span> is a linear model that estimates sparse coefficients. It is useful in some contexts due to its tendency to prefer solutions with fewer parameter values, effectively reducing the number of variables upon which the given solution is dependent. For this reason, the Lasso and its variants are fundamental to the field of compressed sensing. Under certain conditions, it can recover the exact set of non-zero weights (see Compressive sensing: tomography reconstruction with L1 prior (Lasso)).</p></body></html>"))
        self.minalphaLabel.setText(("Minimum Alpha"))
        self.maxalpha_label.setText(("Maximum Alpha"))
        self.nalphas_label.setText(("# of Alphas"))
        self.maxNumOfIterationsLabel.setText(("Max # of iterations"))
        self.maxNumOfIterationsLineEdit.setText(("1000"))
        self.toleranceLabel.setText(("Tolerance"))
        self.toleranceLineEdit.setToolTip(("<html><head/><body><p>tol : float, optional</p><p>The tolerance for the optimization: if the updates are smaller than tol, the optimization code checks the dual gap for optimality and continues until it is smaller than tol</p></body></html>"))
        self.toleranceLineEdit.setText(("0.0001"))
        self.fitInterceptLabel.setText(("Fit Intercept"))
        __sortingEnabled = self.fit_intercept_list.isSortingEnabled()
        self.fit_intercept_list.setSortingEnabled(False)
        item = self.fit_intercept_list.item(0)
        item.setText(("True"))
        item = self.fit_intercept_list.item(1)
        item.setText(("False"))
        self.fit_intercept_list.setSortingEnabled(__sortingEnabled)
        self.forcePositiveCoefficientsLabel.setText(("Force positive coefficients"))
        __sortingEnabled = self.forcePositive_list.isSortingEnabled()
        self.forcePositive_list.setSortingEnabled(False)
        item = self.forcePositive_list.item(0)
        item.setText(("True"))
        item = self.forcePositive_list.item(1)
        item.setText(("False"))
        self.forcePositive_list.setSortingEnabled(__sortingEnabled)


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())




from PyQt5 import QtWidgets
from sklearn.ensemble import IsolationForest

from point_spectra_gui.ui.outliers_IsolationForest import Ui_Form
from point_spectra_gui.util.Modules import Modules


class Ui_Form(Ui_Form, IsolationForest, Modules):
    def setupUi(self, Form):
        super().setupUi(Form)
        self.checkMinAndMax()
        self.connectWidgets()

    def get_widget(self):
        return self.groupBox

    def setHidden(self, bool):
        self.get_widget().setHidden(bool)

    def connectWidgets(self):
        self.n_est_spin.setValue(self.n_estimators)
        self.prop_outliers_spin.setValue(self.contamination)

    def run(self):
        params = {
            'n_estimators': self.n_est_spin.value(),
            'contamination': self.prop_outliers_spin.value(),
            'n_jobs': -1}
        params_key = str(params)
        return params, params_key


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())



from PyQt5 import QtWidgets
from sklearn.neighbors import LocalOutlierFactor
from point_spectra_gui.ui.outliers_LOF import Ui_Form
from point_spectra_gui.util.Modules import Modules


class Ui_Form(Ui_Form, LocalOutlierFactor, Modules):
    def setupUi(self, Form):
        super().setupUi(Form)
        self.checkMinAndMax()
        self.connectWidgets()

    def get_widget(self):
        return self.groupBox

    def setHidden(self, bool):
        self.get_widget().setHidden(bool)

    def connectWidgets(self):
        self.n_neighbors_spin.setValue(20)
        self.leaf_size_spin.setValue(30)
        self.contamination_spin.setValue(0.1)


    def run(self):
        metric = self.metric_combo.currentText()
        if metric == 'Euclidean':
            p = 2
        if metric == 'Manhattan':
            p = 1

        params = {
            'n_neighbors': self.n_neighbors_spin.value(),
            'contamination': self.contamination_spin.value(),
            'n_jobs': -1,
            'p': p}

        params_key = str(params)
        return params, params_key


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())



from PyQt5 import QtCore


class PandasModel(QtCore.QAbstractTableModel):
    """
    Class to populate a table view with a pandas dataframe
    """

    def __init__(self, data, parent=None):
        QtCore.QAbstractTableModel.__init__(self, parent)
        self._data = data

    def rowCount(self, parent=None):
        return self._data.shape[0]

    def columnCount(self, parent=None):
        return self._data.shape[1]

    def data(self, index, role=QtCore.Qt.DisplayRole):
        if index.isValid():
            if role == QtCore.Qt.DisplayRole:
                return str(self._data.iloc[index.row(), index.column()])
        return None

    def headerData(self, col, orientation, role):
        if orientation == QtCore.Qt.Horizontal and role == QtCore.Qt.DisplayRole:
            return self._data.columns[col]
        if orientation == QtCore.Qt.Vertical and role == QtCore.Qt.DisplayRole:
            return self._data.index[col]
        return None



import numpy as np
from PyQt5 import QtWidgets, QtCore
from sklearn.linear_model.coordinate_descent import Lasso

from point_spectra_gui.ui.cv_Lasso import Ui_Form
from point_spectra_gui.util.Modules import Modules


class Ui_Form(Ui_Form, Lasso, Modules):
    def setupUi(self, Form):
        super().setupUi(Form)
        self.checkMinAndMax()
        self.connectWidgets()

    def get_widget(self):
        return self.groupBox

    def setHidden(self, bool):
        self.get_widget().setHidden(bool)

    def connectWidgets(self):
        self.minalpha_spin.setDecimals(20)
        self.maxalpha_spin.setDecimals(20)

        self.minalpha_spin.setValue(0.0000001)
        self.maxalpha_spin.setValue(0.01)
        self.nalphas_spin.setValue(100)

        self.fit_intercept_list.setCurrentItem(
            self.fit_intercept_list.findItems(str(self.fit_intercept), QtCore.Qt.MatchExactly)[0])
        self.maxNumOfIterationsLineEdit.setText(str(self.max_iter))
        self.toleranceLineEdit.setText(str(self.tol))
        self.forcePositive_list.setCurrentItem(
            self.forcePositive_list.findItems(str(self.positive), QtCore.Qt.MatchExactly)[0])

    def run(self):
        fit_intercept_items = [i.text() == 'True' for i in self.fit_intercept_list.selectedItems()]
        positive_items = [i.text() == 'True' for i in self.forcePositive_list.selectedItems()]
        alphas = np.logspace(np.log10(self.minalpha_spin.value()), np.log10(self.maxalpha_spin.value()),
                             num=self.nalphas_spin.value())
        params = {'alpha': list(alphas),
                  'fit_intercept': fit_intercept_items,
                  'max_iter': [int(i) for i in self.maxNumOfIterationsLineEdit.text().split(',')],
                  'tol': [float(i) for i in self.toleranceLineEdit.text().split(',')],
                  'precompute': [True],
                  'copy_X': [True],
                  'positive': positive_items,
                  'selection': ['random'],
                  }
        keyparams = {}  # params.pop('alpha')
        keyparams['alpha_min'] = self.minalpha_spin.value()
        keyparams['alpha_max'] = self.maxalpha_spin.value()
        keyparams['n_alpha'] = self.nalphas_spin.value()

        modelkey = str(keyparams)
        return params, modelkey


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())



# -*- coding: utf-8 -*-

# Automatically generated - don't edit.
# Use `python setup.py build_ui` to update it.

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Ignored)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Form.sizePolicy().hasHeightForWidth())
        Form.setSizePolicy(sizePolicy)
        self.verticalLayout = QtWidgets.QVBoxLayout(Form)
        self.verticalLayout.setObjectName("verticalLayout")
        self.formGroupBox = QtWidgets.QGroupBox(Form)
        self.formGroupBox.setObjectName("formGroupBox")
        self.formLayout = QtWidgets.QFormLayout(self.formGroupBox)
        self.formLayout.setFieldGrowthPolicy(QtWidgets.QFormLayout.AllNonFixedFieldsGrow)
        self.formLayout.setObjectName("formLayout")
        self.numOfIterationsLabel = QtWidgets.QLabel(self.formGroupBox)
        self.numOfIterationsLabel.setObjectName("numOfIterationsLabel")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.numOfIterationsLabel)
        self.numOfIterationsSpinBox = QtWidgets.QSpinBox(self.formGroupBox)
        self.numOfIterationsSpinBox.setMaximum(999999999)
        self.numOfIterationsSpinBox.setProperty("value", 300)
        self.numOfIterationsSpinBox.setObjectName("numOfIterationsSpinBox")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.numOfIterationsSpinBox)
        self.toleranceLabel = QtWidgets.QLabel(self.formGroupBox)
        self.toleranceLabel.setObjectName("toleranceLabel")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.toleranceLabel)
        self.toleranceDoubleSpinBox = QtWidgets.QDoubleSpinBox(self.formGroupBox)
        self.toleranceDoubleSpinBox.setDecimals(8)
        self.toleranceDoubleSpinBox.setSingleStep(0.001)
        self.toleranceDoubleSpinBox.setProperty("value", 0.001)
        self.toleranceDoubleSpinBox.setObjectName("toleranceDoubleSpinBox")
        self.formLayout.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.toleranceDoubleSpinBox)
        self.alpha1Label = QtWidgets.QLabel(self.formGroupBox)
        self.alpha1Label.setObjectName("alpha1Label")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.alpha1Label)
        self.alpha1DoubleSpinBox = QtWidgets.QDoubleSpinBox(self.formGroupBox)
        self.alpha1DoubleSpinBox.setDecimals(5)
        self.alpha1DoubleSpinBox.setSingleStep(0.001)
        self.alpha1DoubleSpinBox.setProperty("value", 0.001)
        self.alpha1DoubleSpinBox.setObjectName("alpha1DoubleSpinBox")
        self.formLayout.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.alpha1DoubleSpinBox)
        self.alpha2Label = QtWidgets.QLabel(self.formGroupBox)
        self.alpha2Label.setObjectName("alpha2Label")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.alpha2Label)
        self.alpha2DoubleSpinBox = QtWidgets.QDoubleSpinBox(self.formGroupBox)
        self.alpha2DoubleSpinBox.setDecimals(8)
        self.alpha2DoubleSpinBox.setSingleStep(1e-06)
        self.alpha2DoubleSpinBox.setProperty("value", 1e-06)
        self.alpha2DoubleSpinBox.setObjectName("alpha2DoubleSpinBox")
        self.formLayout.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.alpha2DoubleSpinBox)
        self.lambdaLabel = QtWidgets.QLabel(self.formGroupBox)
        self.lambdaLabel.setObjectName("lambdaLabel")
        self.formLayout.setWidget(4, QtWidgets.QFormLayout.LabelRole, self.lambdaLabel)
        self.lambdaDoubleSpinBox = QtWidgets.QDoubleSpinBox(self.formGroupBox)
        self.lambdaDoubleSpinBox.setDecimals(8)
        self.lambdaDoubleSpinBox.setSingleStep(1e-06)
        self.lambdaDoubleSpinBox.setProperty("value", 1e-06)
        self.lambdaDoubleSpinBox.setObjectName("lambdaDoubleSpinBox")
        self.formLayout.setWidget(4, QtWidgets.QFormLayout.FieldRole, self.lambdaDoubleSpinBox)
        self.lambdaLabel_2 = QtWidgets.QLabel(self.formGroupBox)
        self.lambdaLabel_2.setObjectName("lambdaLabel_2")
        self.formLayout.setWidget(5, QtWidgets.QFormLayout.LabelRole, self.lambdaLabel_2)
        self.lambdaDoubleSpinBox_2 = QtWidgets.QDoubleSpinBox(self.formGroupBox)
        self.lambdaDoubleSpinBox_2.setDecimals(8)
        self.lambdaDoubleSpinBox_2.setSingleStep(1e-06)
        self.lambdaDoubleSpinBox_2.setProperty("value", 1e-06)
        self.lambdaDoubleSpinBox_2.setObjectName("lambdaDoubleSpinBox_2")
        self.formLayout.setWidget(5, QtWidgets.QFormLayout.FieldRole, self.lambdaDoubleSpinBox_2)
        self.thresholdLambdaLabel = QtWidgets.QLabel(self.formGroupBox)
        self.thresholdLambdaLabel.setObjectName("thresholdLambdaLabel")
        self.formLayout.setWidget(6, QtWidgets.QFormLayout.LabelRole, self.thresholdLambdaLabel)
        self.thresholdLambdaSpinBox = QtWidgets.QSpinBox(self.formGroupBox)
        self.thresholdLambdaSpinBox.setMaximum(999999999)
        self.thresholdLambdaSpinBox.setProperty("value", 100000)
        self.thresholdLambdaSpinBox.setObjectName("thresholdLambdaSpinBox")
        self.formLayout.setWidget(6, QtWidgets.QFormLayout.FieldRole, self.thresholdLambdaSpinBox)
        self.fitInterceptLabel = QtWidgets.QLabel(self.formGroupBox)
        self.fitInterceptLabel.setObjectName("fitInterceptLabel")
        self.formLayout.setWidget(7, QtWidgets.QFormLayout.LabelRole, self.fitInterceptLabel)
        self.fitInterceptCheckBox = QtWidgets.QCheckBox(self.formGroupBox)
        self.fitInterceptCheckBox.setChecked(True)
        self.fitInterceptCheckBox.setObjectName("fitInterceptCheckBox")
        self.formLayout.setWidget(7, QtWidgets.QFormLayout.FieldRole, self.fitInterceptCheckBox)
        self.normalizeLabel = QtWidgets.QLabel(self.formGroupBox)
        self.normalizeLabel.setObjectName("normalizeLabel")
        self.formLayout.setWidget(8, QtWidgets.QFormLayout.LabelRole, self.normalizeLabel)
        self.normalizeCheckBox = QtWidgets.QCheckBox(self.formGroupBox)
        self.normalizeCheckBox.setObjectName("normalizeCheckBox")
        self.formLayout.setWidget(8, QtWidgets.QFormLayout.FieldRole, self.normalizeCheckBox)
        self.verticalLayout.addWidget(self.formGroupBox)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)
        Form.setTabOrder(self.numOfIterationsSpinBox, self.toleranceDoubleSpinBox)
        Form.setTabOrder(self.toleranceDoubleSpinBox, self.alpha1DoubleSpinBox)
        Form.setTabOrder(self.alpha1DoubleSpinBox, self.alpha2DoubleSpinBox)
        Form.setTabOrder(self.alpha2DoubleSpinBox, self.lambdaDoubleSpinBox)
        Form.setTabOrder(self.lambdaDoubleSpinBox, self.thresholdLambdaSpinBox)
        Form.setTabOrder(self.thresholdLambdaSpinBox, self.fitInterceptCheckBox)
        Form.setTabOrder(self.fitInterceptCheckBox, self.normalizeCheckBox)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(("Form"))
        self.formGroupBox.setTitle(("ARD"))
        self.numOfIterationsLabel.setText(("# of iterations"))
        self.numOfIterationsSpinBox.setToolTip(("Maximum number of iterations. Default is 300"))
        self.numOfIterationsSpinBox.setWhatsThis(("http://scikit-learn.org/stable/modules/generated/sklearn.linear_model.ARDRegression.html"))
        self.toleranceLabel.setText(("Tolerance"))
        self.toleranceDoubleSpinBox.setToolTip(("Stop the algorithm if w has converged. Default is 1.e-3."))
        self.toleranceDoubleSpinBox.setWhatsThis(("http://scikit-learn.org/stable/modules/generated/sklearn.linear_model.ARDRegression.html"))
        self.alpha1Label.setText(("Alpha 1"))
        self.alpha1DoubleSpinBox.setWhatsThis(("http://scikit-learn.org/stable/modules/generated/sklearn.linear_model.ARDRegression.html"))
        self.alpha2Label.setText(("Alpha 2"))
        self.alpha2DoubleSpinBox.setWhatsThis(("http://scikit-learn.org/stable/modules/generated/sklearn.linear_model.ARDRegression.html"))
        self.lambdaLabel.setText(("Lambda"))
        self.lambdaDoubleSpinBox.setWhatsThis(("http://scikit-learn.org/stable/modules/generated/sklearn.linear_model.ARDRegression.html"))
        self.lambdaLabel_2.setText(("Lambda"))
        self.lambdaDoubleSpinBox_2.setWhatsThis(("http://scikit-learn.org/stable/modules/generated/sklearn.linear_model.ARDRegression.html"))
        self.thresholdLambdaLabel.setText(("Threshold Lambda"))
        self.thresholdLambdaSpinBox.setToolTip(("threshold for removing (pruning) weights with high precision from the\n"
"computation. Default is 1.e+4."))
        self.thresholdLambdaSpinBox.setWhatsThis(("http://scikit-learn.org/stable/modules/generated/sklearn.linear_model.ARDRegression.html"))
        self.fitInterceptLabel.setText(("Fit Intercept"))
        self.fitInterceptCheckBox.setToolTip(_translate("Form", "whether to calculate the intercept for this model. If set to false,\n"
"no intercept will be used in calculations (e.g. data is expected to\n"
"be already centered). Default is True."))
        self.fitInterceptCheckBox.setWhatsThis(("http://scikit-learn.org/stable/modules/generated/sklearn.linear_model.ARDRegression.html"))
        self.fitInterceptCheckBox.setText(("calculate the intercept for this model"))
        self.normalizeLabel.setText(("Normalize"))
        self.normalizeCheckBox.setToolTip(_translate("Form", "This parameter is ignored when fit_intercept is set to False. If True,\n"
"the regressors X will be normalized before regression by subtracting\n"
"the mean and dividing by the l2-norm. If you wish to standardize,\n"
"please use sklearn.preprocessing.StandardScaler before calling fit on\n"
"an estimator with normalize=False."))
        self.normalizeCheckBox.setWhatsThis(("http://scikit-learn.org/stable/modules/generated/sklearn.linear_model.ARDRegression.html"))
        self.normalizeCheckBox.setText(("regressors X will be normlized before regression"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())




from PyQt5 import QtWidgets
from libpysat.transform.baseline_code.airpls import AirPLS

from point_spectra_gui.ui.AirPLS import Ui_Form
from point_spectra_gui.util.Modules import Modules


class Ui_Form(Ui_Form, Modules):
    def setupUi(self, Form):
        super().setupUi(Form)
        self.checkMinAndMax()
        Modules.setupUi(self, Form)

    def get_widget(self):
        return self.groupbox

    def setHidden(self, bool):
        self.get_widget().setHidden(bool)

    def connectWidgets(self):
        airPLS = AirPLS()
        self.smoothnessSpinBox.setValue(airPLS.smoothness_)
        self.convergenceThresholdDoubleSpinBox.setValue(airPLS.conv_thresh_)
        self.maxNumOfIterationsSpinBox.setValue(airPLS.max_iters_)

    def run(self):
        methodParameters = {'smoothness_': float(self.smoothnessSpinBox.value()),
                            'conv_thresh_': int(self.convergenceThresholdDoubleSpinBox.value()),
                            'max_iters_': float(self.maxNumOfIterationsSpinBox.value())}

        return methodParameters, self.getChangedValues(methodParameters, AirPLS())


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())



# -*- coding: utf-8 -*-

# Automatically generated - don't edit.
# Use `python setup.py build_ui` to update it.

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Ignored)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Form.sizePolicy().hasHeightForWidth())
        Form.setSizePolicy(sizePolicy)
        self.verticalLayout = QtWidgets.QVBoxLayout(Form)
        self.verticalLayout.setObjectName("verticalLayout")
        self.groupBox = QtWidgets.QGroupBox(Form)
        self.groupBox.setObjectName("groupBox")
        self.ENLayout = QtWidgets.QVBoxLayout(self.groupBox)
        self.ENLayout.setObjectName("ENLayout")
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.elasticNetGroupBox = QtWidgets.QGroupBox(self.groupBox)
        self.elasticNetGroupBox.setObjectName("elasticNetGroupBox")
        self.ElasticNet = QtWidgets.QFormLayout(self.elasticNetGroupBox)
        self.ElasticNet.setFieldGrowthPolicy(QtWidgets.QFormLayout.AllNonFixedFieldsGrow)
        self.ElasticNet.setObjectName("ElasticNet")
        self.enalphaLabel = QtWidgets.QLabel(self.elasticNetGroupBox)
        self.enalphaLabel.setObjectName("enalphaLabel")
        self.ElasticNet.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.enalphaLabel)
        self.alpha_text = QtWidgets.QLineEdit(self.elasticNetGroupBox)
        self.alpha_text.setObjectName("alpha_text")
        self.ElasticNet.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.alpha_text)
        self.enl1_ratioLabel = QtWidgets.QLabel(self.elasticNetGroupBox)
        self.enl1_ratioLabel.setObjectName("enl1_ratioLabel")
        self.ElasticNet.setWidget(1, QtWidgets.QFormLayout.LabelRole, self.enl1_ratioLabel)
        self.enl1_ratioDoubleSpinBox = QtWidgets.QDoubleSpinBox(self.elasticNetGroupBox)
        self.enl1_ratioDoubleSpinBox.setObjectName("enl1_ratioDoubleSpinBox")
        self.ElasticNet.setWidget(1, QtWidgets.QFormLayout.FieldRole, self.enl1_ratioDoubleSpinBox)
        self.enfit_interceptLabel = QtWidgets.QLabel(self.elasticNetGroupBox)
        self.enfit_interceptLabel.setObjectName("enfit_interceptLabel")
        self.ElasticNet.setWidget(4, QtWidgets.QFormLayout.LabelRole, self.enfit_interceptLabel)
        self.enfit_interceptCheckBox = QtWidgets.QCheckBox(self.elasticNetGroupBox)
        self.enfit_interceptCheckBox.setObjectName("enfit_interceptCheckBox")
        self.ElasticNet.setWidget(4, QtWidgets.QFormLayout.FieldRole, self.enfit_interceptCheckBox)
        self.enmax_iterLabel = QtWidgets.QLabel(self.elasticNetGroupBox)
        self.enmax_iterLabel.setObjectName("enmax_iterLabel")
        self.ElasticNet.setWidget(2, QtWidgets.QFormLayout.LabelRole, self.enmax_iterLabel)
        self.enmax_iterSpinBox = QtWidgets.QSpinBox(self.elasticNetGroupBox)
        self.enmax_iterSpinBox.setObjectName("enmax_iterSpinBox")
        self.ElasticNet.setWidget(2, QtWidgets.QFormLayout.FieldRole, self.enmax_iterSpinBox)
        self.entolLabel = QtWidgets.QLabel(self.elasticNetGroupBox)
        self.entolLabel.setObjectName("entolLabel")
        self.ElasticNet.setWidget(3, QtWidgets.QFormLayout.LabelRole, self.entolLabel)
        self.entolDoubleSpinBox = QtWidgets.QDoubleSpinBox(self.elasticNetGroupBox)
        self.entolDoubleSpinBox.setObjectName("entolDoubleSpinBox")
        self.ElasticNet.setWidget(3, QtWidgets.QFormLayout.FieldRole, self.entolDoubleSpinBox)
        self.enpositiveLabel = QtWidgets.QLabel(self.elasticNetGroupBox)
        self.enpositiveLabel.setObjectName("enpositiveLabel")
        self.ElasticNet.setWidget(5, QtWidgets.QFormLayout.LabelRole, self.enpositiveLabel)
        self.enpositiveCheckBox = QtWidgets.QCheckBox(self.elasticNetGroupBox)
        self.enpositiveCheckBox.setObjectName("enpositiveCheckBox")
        self.ElasticNet.setWidget(5, QtWidgets.QFormLayout.FieldRole, self.enpositiveCheckBox)
        self.horizontalLayout.addWidget(self.elasticNetGroupBox)
        self.ENLayout.addLayout(self.horizontalLayout)
        self.verticalLayout.addWidget(self.groupBox)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(("Form"))
        self.elasticNetGroupBox.setTitle(("Elastic Net"))
        self.enalphaLabel.setText(("Alpha"))
        self.enl1_ratioLabel.setText(("L1 Ratio"))
        self.enl1_ratioDoubleSpinBox.setToolTip(_translate("Form", "The ElasticNet mixing parameter, with 0 <= l1_ratio <= 1. For l1_ratio\n"
"= 0 the penalty is an L2 penalty. For l1_ratio = 1 it is an L1 penalty.\n"
"For 0 < l1_ratio < 1, the penalty is a combination of L1 and L2."))
        self.enl1_ratioDoubleSpinBox.setWhatsThis(("http://scikit-learn.org/stable/modules/generated/sklearn.linear_model.ElasticNet.html"))
        self.enfit_interceptLabel.setText(("Fit Intercept"))
        self.enfit_interceptCheckBox.setToolTip(_translate("Form", "Whether the intercept should be estimated or not. If False, the data\n"
"is assumed to be already centered."))
        self.enfit_interceptCheckBox.setWhatsThis(("http://scikit-learn.org/stable/modules/generated/sklearn.linear_model.ElasticNet.html"))
        self.enmax_iterLabel.setText(("Max # of iterations"))
        self.enmax_iterSpinBox.setToolTip(("The maximum number of iterations"))
        self.enmax_iterSpinBox.setWhatsThis(("http://scikit-learn.org/stable/modules/generated/sklearn.linear_model.ElasticNet.html"))
        self.entolLabel.setText(("Tolerance"))
        self.entolDoubleSpinBox.setToolTip(("The tolerance for the optimization:"))
        self.entolDoubleSpinBox.setWhatsThis(("http://scikit-learn.org/stable/modules/generated/sklearn.linear_model.ElasticNet.html"))
        self.enpositiveLabel.setText(("Positive"))
        self.enpositiveCheckBox.setToolTip(("When set to True, forces the coefficients to be positive."))
        self.enpositiveCheckBox.setWhatsThis(("http://scikit-learn.org/stable/modules/generated/sklearn.linear_model.ElasticNet.html"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())




# -*- coding: utf-8 -*-

# Automatically generated - don't edit.
# Use `python setup.py build_ui` to update it.

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_AboutQT(object):
    def setupUi(self, AboutQT):
        AboutQT.setObjectName("AboutQT")
        self.verticalLayout = QtWidgets.QVBoxLayout(AboutQT)
        self.verticalLayout.setObjectName("verticalLayout")
        self.textBrowser = QtWidgets.QTextBrowser(AboutQT)
        self.textBrowser.setObjectName("textBrowser")
        self.verticalLayout.addWidget(self.textBrowser)

        self.retranslateUi(AboutQT)
        QtCore.QMetaObject.connectSlotsByName(AboutQT)

    def retranslateUi(self, AboutQT):
        _translate = QtCore.QCoreApplication.translate
        AboutQT.setWindowTitle(("About Qt"))
        self.textBrowser.setHtml(_translate("AboutQT", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'MS Shell Dlg 2\'; font-size:8.25pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:24pt;\">What is PyQt?</span></p>\n"
"<p style=\" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:12pt;\">PyQt is a set of Python v2 and v3 bindings for The Qt Company\'s Qt application framework and runs on all platforms supported by Qt including Windows, OS X, Linux, iOS and Android. PyQt5 supports Qt v5. PyQt4 supports Qt v4 and will build against Qt v5. The bindings are implemented as a set of Python modules and contain over 1,000 classes. </span></p>\n"
"<p style=\" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:24pt;\">Why PyQt? </span></p>\n"
"<p style=\" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:12pt;\">PyQt brings together the Qt C++ cross-platform application framework and the cross-platform interpreted language Python. </span></p>\n"
"<p style=\" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:12pt;\">Qt is more than a GUI toolkit. It includes abstractions of network sockets, threads, Unicode, regular expressions, SQL databases, SVG, OpenGL, XML, a fully functional web browser, a help system, a multimedia framework, as well as a rich collection of GUI widgets. </span></p>\n"
"<p style=\" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:12pt;\">Qt classes employ a signal/slot mechanism for communicating between objects that is type safe but loosely coupled making it easy to create re-usable software components. </span></p>\n"
"<p style=\" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:12pt;\">Qt also includes Qt Designer, a graphical user interface designer. PyQt is able to generate Python code from Qt Designer. It is also possible to add new GUI controls written in Python to Qt Designer. </span></p>\n"
"<p style=\" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:12pt;\">Python is a simple but powerful object-orientated language. Its simplicity makes it easy to learn, but its power means that large and complex applications can be created. Its interpreted nature means that Python programmers are very productive because there is no edit/compile/link/run development cycle. </span></p>\n"
"<p style=\" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:12pt;\">Much of Python\'s power comes from its comprehensive set of extension modules providing a wide variety of functions including HTTP servers, XML parsers, database access, data compression tools and, of course, graphical user interfaces. Extension modules are usually implemented in either Python, C or C++. Using tools such as SIP it is relatively straight forward to create an extension module that encapsulates an existing C or C++ library. Used in this way, Python can then become the glue to create new applications from established libraries. </span></p>\n"
"<p style=\" margin-top:12px; margin-bottom:12px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:12pt;\">PyQt combines all the advantages of Qt and Python. A programmer has all the power of Qt, but is able to exploit it with the simplicity of Python.</span></p></body></html>"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    AboutQT = QtWidgets.QWidget()
    ui = Ui_AboutQT()
    ui.setupUi(AboutQT)
    AboutQT.show()
    sys.exit(app.exec_())




import pickle
import json
from PyQt5 import QtWidgets, QtGui

from point_spectra_gui.ui.SaveTrainedModel import Ui_Form
from point_spectra_gui.util.Modules import Modules
#from point_spectra_gui.core.MainWindow import MainWindow

class SaveTrainedModel(Ui_Form, Modules):
    def setupUi(self, Form):
        super().setupUi(Form)
        Modules.setupUi(self, Form)

    def get_widget(self):
        return self.groupBox

    def on_savePushButton_clicked(self, lineEdit):
        self.filename, _filter = QtWidgets.QFileDialog.getSaveFileName(None, "Specify save file name", self.outpath, "(*.tram)")
        lineEdit.setText(self.filename)
        if lineEdit.text() == "":
            lineEdit.setText("*.tram")

    def connectWidgets(self):
        self.setComboBox(self.choosemodel_comboBox, self.modelkeys)
        self.savePushButton.clicked.connect(lambda: self.on_savePushButton_clicked(self.saveLineEdit))

    def run(self):
        modelkey = self.choosemodel_comboBox.currentText()
        # add the data into a list [0. 1]
        # list[0] will hold the dictionary data of the UI
        # TODO Let the user decide what modelkey and model they want to save
        # list[1] will hold the modelkeys
        # list[2] will hold the self.models data
        list = []
        #list.append(json.dumps(MainWindow.getWidgetItems(self), indent=4))
        list.append(modelkey)
        list.append(self.models[modelkey])
        try:
            print(self.filename)
            with open(self.filename, 'wb') as fp:
                pickle.dump(list, fp)
        except Exception as e:
            print("Could not save your trained model: ", e)



if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = SaveTrainedModel()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())



import pandas as pd
from PyQt5 import QtWidgets
from point_spectra_gui.util.spectral_data import spectral_data

from point_spectra_gui.ui.LoadData import Ui_loadData
from point_spectra_gui.util.Modules import Modules


class LoadData(Ui_loadData, Modules):
    """
    Loads the data into the UI.
    The data needs to be a *.csv in order for this application to work
    """
    count = -1

    def __init__(self):
        LoadData.count += 1
        self.curr_count = LoadData.count
        print('Added LoadData with ID {}'.format(self.curr_count))

    def delete(self):
        try:
            LoadData.count -= 1
            del self.data[self.datakeys[-1]]
            del self.datakeys[-1]
        except IndexError:
            pass

    def setupUi(self, Form):
        super().setupUi(Form)
        Modules.setupUi(self, Form)

    def get_widget(self):
        return self.groupBox

    def connectWidgets(self):
        self.newFilePushButton.clicked.connect(lambda: self.getDataButton_clicked(self.fileNameLineEdit))

    def getDataButton_clicked(self, lineEdit):
        filename, _filter = QtWidgets.QFileDialog.getOpenFileName(None, "Open Data File", self.outpath, "(*.csv)")
        lineEdit.setText(filename)
        if lineEdit.text() == "":
            lineEdit.setText("*.csv")

    def setup(self):
        """
        The setup here is only doing the first 2 rows of our dataset
        This will cut down on time to load.

        :return:
        """
        try:
            filename = self.fileNameLineEdit.text()
            keyname = self.dataSetNameLineEdit.text()
            self.data[keyname] = spectral_data(pd.read_csv(filename, header=[0, 1], verbose=True, nrows=2))
            self.list_amend(self.datakeys, self.curr_count, keyname)
        except:
            pass

    def run(self):
        filename = self.fileNameLineEdit.text()
        keyname = self.dataSetNameLineEdit.text()
        print('Loading data file: ' + str(filename))
        self.data[keyname] = spectral_data(pd.read_csv(filename, header=[0, 1], verbose=True))
        self.list_amend(self.datakeys, self.curr_count, keyname)


if __name__ == "__main__":
    import sys

    app = QtWidgets.QApplication(sys.argv)

    Form = QtWidgets.QWidget()
    ui = LoadData()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())



# -*- coding: utf-8 -*-

# Automatically generated - don't edit.
# Use `python setup.py build_ui` to update it.

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Ignored)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Form.sizePolicy().hasHeightForWidth())
        Form.setSizePolicy(sizePolicy)
        self.verticalLayout = QtWidgets.QVBoxLayout(Form)
        self.verticalLayout.setObjectName("verticalLayout")
        self.groupBox = QtWidgets.QGroupBox(Form)
        self.groupBox.setObjectName("groupBox")
        self.formLayout = QtWidgets.QFormLayout(self.groupBox)
        self.formLayout.setFieldGrowthPolicy(QtWidgets.QFormLayout.AllNonFixedFieldsGrow)
        self.formLayout.setObjectName("formLayout")
        self.fitInterceptLabel = QtWidgets.QLabel(self.groupBox)
        self.fitInterceptLabel.setObjectName("fitInterceptLabel")
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.fitInterceptLabel)
        self.fit_intercept_list = QtWidgets.QListWidget(self.groupBox)
        self.fit_intercept_list.setMaximumSize(QtCore.QSize(16777215, 50))
        self.fit_intercept_list.setSelectionMode(QtWidgets.QAbstractItemView.MultiSelection)
        self.fit_intercept_list.setObjectName("fit_intercept_list")
        item = QtWidgets.QListWidgetItem()
        self.fit_intercept_list.addItem(item)
        item = QtWidgets.QListWidgetItem()
        self.fit_intercept_list.addItem(item)
        self.formLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.fit_intercept_list)
        self.verticalLayout.addWidget(self.groupBox)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(("Form"))
        self.fitInterceptLabel.setText(("Fit Intercept"))
        __sortingEnabled = self.fit_intercept_list.isSortingEnabled()
        self.fit_intercept_list.setSortingEnabled(False)
        item = self.fit_intercept_list.item(0)
        item.setText(("True"))
        item = self.fit_intercept_list.item(1)
        item.setText(("False"))
        self.fit_intercept_list.setSortingEnabled(__sortingEnabled)


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())




# -*- coding: utf-8 -*-

# Automatically generated - don't edit.
# Use `python setup.py build_ui` to update it.

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Form(object):
    def setupUi(self, Form):
        Form.setObjectName("Form")
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Ignored)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(Form.sizePolicy().hasHeightForWidth())
        Form.setSizePolicy(sizePolicy)
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(Form)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.groupBox = QtWidgets.QGroupBox(Form)
        self.groupBox.setObjectName("groupBox")
        self.Normalization = QtWidgets.QVBoxLayout(self.groupBox)
        self.Normalization.setObjectName("Normalization")
        self.chooseDataFormLayout = QtWidgets.QFormLayout()
        self.chooseDataFormLayout.setObjectName("chooseDataFormLayout")
        self.chooseDataLabel = QtWidgets.QLabel(self.groupBox)
        self.chooseDataLabel.setObjectName("chooseDataLabel")
        self.chooseDataFormLayout.setWidget(0, QtWidgets.QFormLayout.LabelRole, self.chooseDataLabel)
        self.chooseDataComboBox = QtWidgets.QComboBox(self.groupBox)
        self.chooseDataComboBox.setObjectName("chooseDataComboBox")
        self.chooseDataFormLayout.setWidget(0, QtWidgets.QFormLayout.FieldRole, self.chooseDataComboBox)
        self.Normalization.addLayout(self.chooseDataFormLayout)
        self.varToNormalizeVerticalLayout = QtWidgets.QVBoxLayout()
        self.varToNormalizeVerticalLayout.setObjectName("varToNormalizeVerticalLayout")
        self.varToNormalizeLabel = QtWidgets.QLabel(self.groupBox)
        self.varToNormalizeLabel.setObjectName("varToNormalizeLabel")
        self.varToNormalizeVerticalLayout.addWidget(self.varToNormalizeLabel)
        self.varToNormalizeListWidget = QtWidgets.QListWidget(self.groupBox)
        self.varToNormalizeListWidget.setObjectName("varToNormalizeListWidget")
        self.varToNormalizeVerticalLayout.addWidget(self.varToNormalizeListWidget)
        self.Normalization.addLayout(self.varToNormalizeVerticalLayout)
        self.waveLengthLayout = QtWidgets.QGridLayout()
        self.waveLengthLayout.setObjectName("waveLengthLayout")
        self.hidden_6 = QtWidgets.QCheckBox(self.groupBox)
        self.hidden_6.setObjectName("hidden_6")
        self.waveLengthLayout.addWidget(self.hidden_6, 5, 4, 1, 1)
        self.hidden_4 = QtWidgets.QCheckBox(self.groupBox)
        self.hidden_4.setObjectName("hidden_4")
        self.waveLengthLayout.addWidget(self.hidden_4, 3, 4, 1, 1)
        self.hidden_1 = QtWidgets.QCheckBox(self.groupBox)
        self.hidden_1.setChecked(False)
        self.hidden_1.setObjectName("hidden_1")
        self.waveLengthLayout.addWidget(self.hidden_1, 0, 4, 1, 1)
        self.minWvlLabel = QtWidgets.QLabel(self.groupBox)
        self.minWvlLabel.setObjectName("minWvlLabel")
        self.waveLengthLayout.addWidget(self.minWvlLabel, 0, 0, 1, 1)
        self.maxWvlLabel = QtWidgets.QLabel(self.groupBox)
        self.maxWvlLabel.setObjectName("maxWvlLabel")
        self.waveLengthLayout.addWidget(self.maxWvlLabel, 0, 2, 1, 1)
        self.minWvlLabel_2 = QtWidgets.QLabel(self.groupBox)
        self.minWvlLabel_2.setObjectName("minWvlLabel_2")
        self.waveLengthLayout.addWidget(self.minWvlLabel_2, 1, 0, 1, 1)
        self.maxWvlLabel_2 = QtWidgets.QLabel(self.groupBox)
        self.maxWvlLabel_2.setObjectName("maxWvlLabel_2")
        self.waveLengthLayout.addWidget(self.maxWvlLabel_2, 1, 2, 1, 1)
        self.minWvlLabel_3 = QtWidgets.QLabel(self.groupBox)
        self.minWvlLabel_3.setObjectName("minWvlLabel_3")
        self.waveLengthLayout.addWidget(self.minWvlLabel_3, 2, 0, 1, 1)
        self.maxWvlLabel_3 = QtWidgets.QLabel(self.groupBox)
        self.maxWvlLabel_3.setObjectName("maxWvlLabel_3")
        self.waveLengthLayout.addWidget(self.maxWvlLabel_3, 2, 2, 1, 1)
        self.minWvlLabel_4 = QtWidgets.QLabel(self.groupBox)
        self.minWvlLabel_4.setObjectName("minWvlLabel_4")
        self.waveLengthLayout.addWidget(self.minWvlLabel_4, 3, 0, 1, 1)
        self.maxWvlLabel_4 = QtWidgets.QLabel(self.groupBox)
        self.maxWvlLabel_4.setObjectName("maxWvlLabel_4")
        self.waveLengthLayout.addWidget(self.maxWvlLabel_4, 3, 2, 1, 1)
        self.minWvlLabel_5 = QtWidgets.QLabel(self.groupBox)
        self.minWvlLabel_5.setObjectName("minWvlLabel_5")
        self.waveLengthLayout.addWidget(self.minWvlLabel_5, 4, 0, 1, 1)
        self.maxWvlLabel_5 = QtWidgets.QLabel(self.groupBox)
        self.maxWvlLabel_5.setObjectName("maxWvlLabel_5")
        self.waveLengthLayout.addWidget(self.maxWvlLabel_5, 4, 2, 1, 1)
        self.minWvlLabel_6 = QtWidgets.QLabel(self.groupBox)
        self.minWvlLabel_6.setObjectName("minWvlLabel_6")
        self.waveLengthLayout.addWidget(self.minWvlLabel_6, 5, 0, 1, 1)
        self.maxWvlLabel_6 = QtWidgets.QLabel(self.groupBox)
        self.maxWvlLabel_6.setObjectName("maxWvlLabel_6")
        self.waveLengthLayout.addWidget(self.maxWvlLabel_6, 5, 2, 1, 1)
        self.minWvlLabel_7 = QtWidgets.QLabel(self.groupBox)
        self.minWvlLabel_7.setObjectName("minWvlLabel_7")
        self.waveLengthLayout.addWidget(self.minWvlLabel_7, 6, 0, 1, 1)
        self.maxWvlLabel_7 = QtWidgets.QLabel(self.groupBox)
        self.maxWvlLabel_7.setObjectName("maxWvlLabel_7")
        self.waveLengthLayout.addWidget(self.maxWvlLabel_7, 6, 2, 1, 1)
        self.minWvlLabel_8 = QtWidgets.QLabel(self.groupBox)
        self.minWvlLabel_8.setObjectName("minWvlLabel_8")
        self.waveLengthLayout.addWidget(self.minWvlLabel_8, 7, 0, 1, 1)
        self.maxWvlLabel_8 = QtWidgets.QLabel(self.groupBox)
        self.maxWvlLabel_8.setObjectName("maxWvlLabel_8")
        self.waveLengthLayout.addWidget(self.maxWvlLabel_8, 7, 2, 1, 1)
        self.minWvlLabel_9 = QtWidgets.QLabel(self.groupBox)
        self.minWvlLabel_9.setObjectName("minWvlLabel_9")
        self.waveLengthLayout.addWidget(self.minWvlLabel_9, 8, 0, 1, 1)
        self.maxWvlLabel_9 = QtWidgets.QLabel(self.groupBox)
        self.maxWvlLabel_9.setObjectName("maxWvlLabel_9")
        self.waveLengthLayout.addWidget(self.maxWvlLabel_9, 8, 2, 1, 1)
        self.minWvlLabel_10 = QtWidgets.QLabel(self.groupBox)
        self.minWvlLabel_10.setObjectName("minWvlLabel_10")
        self.waveLengthLayout.addWidget(self.minWvlLabel_10, 9, 0, 1, 1)
        self.maxWvlLabel_10 = QtWidgets.QLabel(self.groupBox)
        self.maxWvlLabel_10.setObjectName("maxWvlLabel_10")
        self.waveLengthLayout.addWidget(self.maxWvlLabel_10, 9, 2, 1, 1)
        self.minWvlLabel_11 = QtWidgets.QLabel(self.groupBox)
        self.minWvlLabel_11.setObjectName("minWvlLabel_11")
        self.waveLengthLayout.addWidget(self.minWvlLabel_11, 10, 0, 1, 1)
        self.maxWvlLabel_11 = QtWidgets.QLabel(self.groupBox)
        self.maxWvlLabel_11.setObjectName("maxWvlLabel_11")
        self.waveLengthLayout.addWidget(self.maxWvlLabel_11, 10, 2, 1, 1)
        self.minWvlLabel_12 = QtWidgets.QLabel(self.groupBox)
        self.minWvlLabel_12.setObjectName("minWvlLabel_12")
        self.waveLengthLayout.addWidget(self.minWvlLabel_12, 11, 0, 1, 1)
        self.maxWvlLabel_12 = QtWidgets.QLabel(self.groupBox)
        self.maxWvlLabel_12.setObjectName("maxWvlLabel_12")
        self.waveLengthLayout.addWidget(self.maxWvlLabel_12, 11, 2, 1, 1)
        self.minWvlLabel_13 = QtWidgets.QLabel(self.groupBox)
        self.minWvlLabel_13.setObjectName("minWvlLabel_13")
        self.waveLengthLayout.addWidget(self.minWvlLabel_13, 12, 0, 1, 1)
        self.maxWvlLabel_13 = QtWidgets.QLabel(self.groupBox)
        self.maxWvlLabel_13.setObjectName("maxWvlLabel_13")
        self.waveLengthLayout.addWidget(self.maxWvlLabel_13, 12, 2, 1, 1)
        self.minWvlLabel_14 = QtWidgets.QLabel(self.groupBox)
        self.minWvlLabel_14.setObjectName("minWvlLabel_14")
        self.waveLengthLayout.addWidget(self.minWvlLabel_14, 13, 0, 1, 1)
        self.maxWvlLabel_14 = QtWidgets.QLabel(self.groupBox)
        self.maxWvlLabel_14.setObjectName("maxWvlLabel_14")
        self.waveLengthLayout.addWidget(self.maxWvlLabel_14, 13, 2, 1, 1)
        self.minWvlLabel_15 = QtWidgets.QLabel(self.groupBox)
        self.minWvlLabel_15.setObjectName("minWvlLabel_15")
        self.waveLengthLayout.addWidget(self.minWvlLabel_15, 14, 0, 1, 1)
        self.maxWvlLabel_15 = QtWidgets.QLabel(self.groupBox)
        self.maxWvlLabel_15.setObjectName("maxWvlLabel_15")
        self.waveLengthLayout.addWidget(self.maxWvlLabel_15, 14, 2, 1, 1)
        self.minWvlSpin = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.minWvlSpin.setObjectName("minWvlSpin")
        self.waveLengthLayout.addWidget(self.minWvlSpin, 0, 1, 1, 1)
        self.minWvlSpin_10 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.minWvlSpin_10.setObjectName("minWvlSpin_10")
        self.waveLengthLayout.addWidget(self.minWvlSpin_10, 9, 1, 1, 1)
        self.minWvlSpin_11 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.minWvlSpin_11.setObjectName("minWvlSpin_11")
        self.waveLengthLayout.addWidget(self.minWvlSpin_11, 10, 1, 1, 1)
        self.minWvlSpin_12 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.minWvlSpin_12.setObjectName("minWvlSpin_12")
        self.waveLengthLayout.addWidget(self.minWvlSpin_12, 11, 1, 1, 1)
        self.minWvlSpin_13 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.minWvlSpin_13.setObjectName("minWvlSpin_13")
        self.waveLengthLayout.addWidget(self.minWvlSpin_13, 12, 1, 1, 1)
        self.minWvlSpin_14 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.minWvlSpin_14.setObjectName("minWvlSpin_14")
        self.waveLengthLayout.addWidget(self.minWvlSpin_14, 13, 1, 1, 1)
        self.minWvlSpin_15 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.minWvlSpin_15.setObjectName("minWvlSpin_15")
        self.waveLengthLayout.addWidget(self.minWvlSpin_15, 14, 1, 1, 1)
        self.minWvlSpin_2 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.minWvlSpin_2.setObjectName("minWvlSpin_2")
        self.waveLengthLayout.addWidget(self.minWvlSpin_2, 1, 1, 1, 1)
        self.minWvlSpin_3 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.minWvlSpin_3.setObjectName("minWvlSpin_3")
        self.waveLengthLayout.addWidget(self.minWvlSpin_3, 2, 1, 1, 1)
        self.minWvlSpin_4 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.minWvlSpin_4.setObjectName("minWvlSpin_4")
        self.waveLengthLayout.addWidget(self.minWvlSpin_4, 3, 1, 1, 1)
        self.minWvlSpin_5 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.minWvlSpin_5.setObjectName("minWvlSpin_5")
        self.waveLengthLayout.addWidget(self.minWvlSpin_5, 4, 1, 1, 1)
        self.minWvlSpin_6 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.minWvlSpin_6.setObjectName("minWvlSpin_6")
        self.waveLengthLayout.addWidget(self.minWvlSpin_6, 5, 1, 1, 1)
        self.minWvlSpin_7 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.minWvlSpin_7.setObjectName("minWvlSpin_7")
        self.waveLengthLayout.addWidget(self.minWvlSpin_7, 6, 1, 1, 1)
        self.minWvlSpin_8 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.minWvlSpin_8.setObjectName("minWvlSpin_8")
        self.waveLengthLayout.addWidget(self.minWvlSpin_8, 7, 1, 1, 1)
        self.minWvlSpin_9 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.minWvlSpin_9.setObjectName("minWvlSpin_9")
        self.waveLengthLayout.addWidget(self.minWvlSpin_9, 8, 1, 1, 1)
        self.maxWvlSpin = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.maxWvlSpin.setObjectName("maxWvlSpin")
        self.waveLengthLayout.addWidget(self.maxWvlSpin, 0, 3, 1, 1)
        self.maxWvlSpin_10 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.maxWvlSpin_10.setObjectName("maxWvlSpin_10")
        self.waveLengthLayout.addWidget(self.maxWvlSpin_10, 9, 3, 1, 1)
        self.maxWvlSpin_11 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.maxWvlSpin_11.setObjectName("maxWvlSpin_11")
        self.waveLengthLayout.addWidget(self.maxWvlSpin_11, 10, 3, 1, 1)
        self.maxWvlSpin_12 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.maxWvlSpin_12.setObjectName("maxWvlSpin_12")
        self.waveLengthLayout.addWidget(self.maxWvlSpin_12, 11, 3, 1, 1)
        self.maxWvlSpin_13 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.maxWvlSpin_13.setObjectName("maxWvlSpin_13")
        self.waveLengthLayout.addWidget(self.maxWvlSpin_13, 12, 3, 1, 1)
        self.maxWvlSpin_14 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.maxWvlSpin_14.setObjectName("maxWvlSpin_14")
        self.waveLengthLayout.addWidget(self.maxWvlSpin_14, 13, 3, 1, 1)
        self.maxWvlSpin_15 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.maxWvlSpin_15.setObjectName("maxWvlSpin_15")
        self.waveLengthLayout.addWidget(self.maxWvlSpin_15, 14, 3, 1, 1)
        self.maxWvlSpin_2 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.maxWvlSpin_2.setObjectName("maxWvlSpin_2")
        self.waveLengthLayout.addWidget(self.maxWvlSpin_2, 1, 3, 1, 1)
        self.maxWvlSpin_3 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.maxWvlSpin_3.setObjectName("maxWvlSpin_3")
        self.waveLengthLayout.addWidget(self.maxWvlSpin_3, 2, 3, 1, 1)
        self.maxWvlSpin_4 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.maxWvlSpin_4.setObjectName("maxWvlSpin_4")
        self.waveLengthLayout.addWidget(self.maxWvlSpin_4, 3, 3, 1, 1)
        self.maxWvlSpin_5 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.maxWvlSpin_5.setObjectName("maxWvlSpin_5")
        self.waveLengthLayout.addWidget(self.maxWvlSpin_5, 4, 3, 1, 1)
        self.maxWvlSpin_6 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.maxWvlSpin_6.setObjectName("maxWvlSpin_6")
        self.waveLengthLayout.addWidget(self.maxWvlSpin_6, 5, 3, 1, 1)
        self.maxWvlSpin_7 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.maxWvlSpin_7.setObjectName("maxWvlSpin_7")
        self.waveLengthLayout.addWidget(self.maxWvlSpin_7, 6, 3, 1, 1)
        self.maxWvlSpin_8 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.maxWvlSpin_8.setObjectName("maxWvlSpin_8")
        self.waveLengthLayout.addWidget(self.maxWvlSpin_8, 7, 3, 1, 1)
        self.maxWvlSpin_9 = QtWidgets.QDoubleSpinBox(self.groupBox)
        self.maxWvlSpin_9.setObjectName("maxWvlSpin_9")
        self.waveLengthLayout.addWidget(self.maxWvlSpin_9, 8, 3, 1, 1)
        self.hidden_5 = QtWidgets.QCheckBox(self.groupBox)
        self.hidden_5.setObjectName("hidden_5")
        self.waveLengthLayout.addWidget(self.hidden_5, 4, 4, 1, 1)
        self.hidden_7 = QtWidgets.QCheckBox(self.groupBox)
        self.hidden_7.setObjectName("hidden_7")
        self.waveLengthLayout.addWidget(self.hidden_7, 6, 4, 1, 1)
        self.hidden_3 = QtWidgets.QCheckBox(self.groupBox)
        self.hidden_3.setObjectName("hidden_3")
        self.waveLengthLayout.addWidget(self.hidden_3, 2, 4, 1, 1)
        self.hidden_9 = QtWidgets.QCheckBox(self.groupBox)
        self.hidden_9.setObjectName("hidden_9")
        self.waveLengthLayout.addWidget(self.hidden_9, 8, 4, 1, 1)
        self.hidden_2 = QtWidgets.QCheckBox(self.groupBox)
        self.hidden_2.setObjectName("hidden_2")
        self.waveLengthLayout.addWidget(self.hidden_2, 1, 4, 1, 1)
        self.hidden_10 = QtWidgets.QCheckBox(self.groupBox)
        self.hidden_10.setObjectName("hidden_10")
        self.waveLengthLayout.addWidget(self.hidden_10, 9, 4, 1, 1)
        self.hidden_13 = QtWidgets.QCheckBox(self.groupBox)
        self.hidden_13.setObjectName("hidden_13")
        self.waveLengthLayout.addWidget(self.hidden_13, 12, 4, 1, 1)
        self.hidden_11 = QtWidgets.QCheckBox(self.groupBox)
        self.hidden_11.setObjectName("hidden_11")
        self.waveLengthLayout.addWidget(self.hidden_11, 10, 4, 1, 1)
        self.hidden_12 = QtWidgets.QCheckBox(self.groupBox)
        self.hidden_12.setObjectName("hidden_12")
        self.waveLengthLayout.addWidget(self.hidden_12, 11, 4, 1, 1)
        self.hidden_14 = QtWidgets.QCheckBox(self.groupBox)
        self.hidden_14.setObjectName("hidden_14")
        self.waveLengthLayout.addWidget(self.hidden_14, 13, 4, 1, 1)
        self.hidden_15 = QtWidgets.QCheckBox(self.groupBox)
        self.hidden_15.setObjectName("hidden_15")
        self.waveLengthLayout.addWidget(self.hidden_15, 14, 4, 1, 1)
        self.hidden_8 = QtWidgets.QCheckBox(self.groupBox)
        self.hidden_8.setObjectName("hidden_8")
        self.waveLengthLayout.addWidget(self.hidden_8, 7, 4, 1, 1)
        self.Normalization.addLayout(self.waveLengthLayout)
        self.index = QtWidgets.QSpinBox(self.groupBox)
        self.index.setProperty("value", 1)
        self.index.setObjectName("index")
        self.Normalization.addWidget(self.index)
        self.addDelRangeLayout = QtWidgets.QHBoxLayout()
        self.addDelRangeLayout.setObjectName("addDelRangeLayout")
        self.add_range_button = QtWidgets.QPushButton(self.groupBox)
        self.add_range_button.setObjectName("add_range_button")
        self.addDelRangeLayout.addWidget(self.add_range_button)
        self.delete_range_button = QtWidgets.QPushButton(self.groupBox)
        self.delete_range_button.setObjectName("delete_range_button")
        self.addDelRangeLayout.addWidget(self.delete_range_button)
        self.Normalization.addLayout(self.addDelRangeLayout)
        self.verticalLayout_3.addWidget(self.groupBox)

        self.retranslateUi(Form)
        QtCore.QMetaObject.connectSlotsByName(Form)

    def retranslateUi(self, Form):
        _translate = QtCore.QCoreApplication.translate
        Form.setWindowTitle(("Form"))
        self.groupBox.setTitle(("Normalization"))
        self.chooseDataLabel.setText(("Choose data"))
        self.varToNormalizeLabel.setText(("Variable to normalize"))
        self.hidden_6.setText(("Hidden"))
        self.hidden_4.setText(("Hidden"))
        self.hidden_1.setText(("Hidden"))
        self.minWvlLabel.setText(("1 Minimum wavelength"))
        self.maxWvlLabel.setText(("Maximum wavelength"))
        self.minWvlLabel_2.setText(("2 Minimum wavelength"))
        self.maxWvlLabel_2.setText(("Maximum wavelength"))
        self.minWvlLabel_3.setText(("3 Minimum wavelength"))
        self.maxWvlLabel_3.setText(("Maximum wavelength"))
        self.minWvlLabel_4.setText(("4 Minimum wavelength"))
        self.maxWvlLabel_4.setText(("Maximum wavelength"))
        self.minWvlLabel_5.setText(("5 Minimum wavelength"))
        self.maxWvlLabel_5.setText(("Maximum wavelength"))
        self.minWvlLabel_6.setText(("6 Minimum wavelength"))
        self.maxWvlLabel_6.setText(("Maximum wavelength"))
        self.minWvlLabel_7.setText(("7 Minimum wavelength"))
        self.maxWvlLabel_7.setText(("Maximum wavelength"))
        self.minWvlLabel_8.setText(("8 Minimum wavelength"))
        self.maxWvlLabel_8.setText(("Maximum wavelength"))
        self.minWvlLabel_9.setText(("9 Minimum wavelength"))
        self.maxWvlLabel_9.setText(("Maximum wavelength"))
        self.minWvlLabel_10.setText(("10 Minimum wavelength"))
        self.maxWvlLabel_10.setText(("Maximum wavelength"))
        self.minWvlLabel_11.setText(("11 Minimum wavelength"))
        self.maxWvlLabel_11.setText(("Maximum wavelength"))
        self.minWvlLabel_12.setText(("12 Minimum wavelength"))
        self.maxWvlLabel_12.setText(("Maximum wavelength"))
        self.minWvlLabel_13.setText(("13 Minimum wavelength"))
        self.maxWvlLabel_13.setText(("Maximum wavelength"))
        self.minWvlLabel_14.setText(("14 Minimum wavelength"))
        self.maxWvlLabel_14.setText(("Maximum wavelength"))
        self.minWvlLabel_15.setText(("15 Minimum wavelength"))
        self.maxWvlLabel_15.setText(("Maximum wavelength"))
        self.hidden_5.setText(("Hidden"))
        self.hidden_7.setText(("Hidden"))
        self.hidden_3.setText(("Hidden"))
        self.hidden_9.setText(("Hidden"))
        self.hidden_2.setText(("Hidden"))
        self.hidden_10.setText(("Hidden"))
        self.hidden_13.setText(("Hidden"))
        self.hidden_11.setText(("Hidden"))
        self.hidden_12.setText(("Hidden"))
        self.hidden_14.setText(("Hidden"))
        self.hidden_15.setText(("Hidden"))
        self.hidden_8.setText(("Hidden"))
        self.add_range_button.setText(("Add Range"))
        self.delete_range_button.setText(("Delete Range"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    Form = QtWidgets.QWidget()
    ui = Ui_Form()
    ui.setupUi(Form)
    Form.show()
    sys.exit(app.exec_())

